@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Iterator, Literal, Tuple
+from typing import Iterator, Literal
 
 from prettyqt import charts
 from prettyqt.qt.QtCharts import QtCharts
@@ -8,8 +8,8 @@ from prettyqt.utils import InvalidParamError, bidict
 
 
 LABELS_POSITIONS = bidict(
-    center=QtCharts.QCategoryAxis.AxisLabelsPositionCenter,
-    on_value=QtCharts.QCategoryAxis.AxisLabelsPositionOnValue,
+    center=QtCharts.QCategoryAxis.AxisLabelsPosition.AxisLabelsPositionCenter,
+    on_value=QtCharts.QCategoryAxis.AxisLabelsPosition.AxisLabelsPositionOnValue,
 )
 
 LabelsPositionStr = Literal["center", "on_value"]
@@ -30,7 +30,7 @@ class CategoryAxis(QtCharts.QCategoryAxis):
     def __iter__(self) -> Iterator[str]:
         return iter(self.categoriesLabels())
 
-    def __add__(self, other: Tuple[str, int]) -> CategoryAxis:
+    def __add__(self, other: tuple[str, int]) -> CategoryAxis:
         self.append(*other)
         return self
 
