@@ -7,21 +7,17 @@ import prettyqt.qt
 from prettyqt.utils import mappers
 
 Qt = QtCore.Qt
+Alignment = Qt.AlignmentFlag
+Orientation = Qt.Orientation
+ItemFlag = Qt.ItemFlag
+DropAction = Qt.DropAction
+Modifier = Qt.KeyboardModifier
+Edge = Qt.Edge
 
 if prettyqt.qt.API != "pyqt6":
-    Alignment = Qt.AlignmentFlag
-    Orientation = Qt.Orientation
-    ItemFlag = Qt.ItemFlag
-    DropAction = Qt.DropAction
-    Modifier = Qt.KeyboardModifier
-    Edge = Qt.Edge
+    ImageConversionFlag = Qt.ImageConversionFlags
 else:
-    Alignment = Qt.Alignment  # type: ignore
-    Orientation = Qt.Orientations  # type: ignore
-    ItemFlag = Qt.ItemFlags  # type: ignore
-    DropAction = Qt.DropActions  # type: ignore
-    Modifier = Qt.KeyboardModifiers  # type: ignore
-    Edge = Qt.Edges  # type: ignore
+    ImageConversionFlag = Qt.ImageConversionFlag  # type: ignore
 
 DISPLAY_ROLE = Qt.ItemDataRole.DisplayRole
 USER_ROLE = Qt.ItemDataRole.UserRole
@@ -86,8 +82,11 @@ KEY_F11 = Qt.Key.Key_F11
 KEY_DELETE = Qt.Key.Key_Delete
 
 
+ThemeStr = Literal["default", "dark"]
+
+
 ALIGNMENTS = mappers.FlagMap(
-    Qt.Alignment,
+    Alignment,
     # none=int(Qt.Alignment(0)),
     left=ALIGN_LEFT,
     right=ALIGN_RIGHT,
@@ -112,7 +111,7 @@ AlignmentStr = Literal[
 ]
 
 SIDES = mappers.FlagMap(
-    Qt.Alignment,
+    Alignment,
     left=Alignment.AlignLeft,
     right=Alignment.AlignRight,
     top=Alignment.AlignTop,
@@ -122,7 +121,7 @@ SIDES = mappers.FlagMap(
 SideStr = Literal["left", "right", "top", "bottom"]
 
 EDGES = mappers.FlagMap(
-    Qt.Edges,
+    Qt.Edge,
     top=Edge.TopEdge,
     left=Edge.LeftEdge,
     right=Edge.RightEdge,
@@ -145,7 +144,7 @@ EdgeStr = Literal[
 ]
 
 H_ALIGNMENT = mappers.FlagMap(
-    Qt.Alignment,
+    Alignment,
     left=Alignment.AlignLeft,
     right=Alignment.AlignRight,
     center=Alignment.AlignHCenter,
@@ -160,7 +159,7 @@ HorizontalAlignmentStr = Literal[
 ]
 
 V_ALIGNMENT = mappers.FlagMap(
-    Qt.Alignment,
+    Alignment,
     top=Alignment.AlignTop,
     bottom=Alignment.AlignBottom,
     center=Alignment.AlignVCenter,
@@ -174,6 +173,26 @@ VerticalAlignmentStr = Literal[
     "baseline",
 ]
 
+MODIFIER_TO_KEY = {
+    QtCore.Qt.KeyboardModifier.ShiftModifier: QtCore.Qt.Modifier.SHIFT,
+    QtCore.Qt.KeyboardModifier.ControlModifier: QtCore.Qt.Modifier.CTRL,
+    QtCore.Qt.KeyboardModifier.AltModifier: QtCore.Qt.Modifier.ALT,
+    QtCore.Qt.KeyboardModifier.MetaModifier: QtCore.Qt.Modifier.META,
+}
+
+KeyboardmodifierStr = Literal[
+    "none", "shift", "ctrl", "alt", "meta", "keypad", "group_switch"
+]
+KEYBOARD_MODIFIERS: bidict[KeyboardmodifierStr, Qt.KeyboardModifier] = bidict(
+    none=Qt.KeyboardModifier.NoModifier,
+    shift=Qt.KeyboardModifier.ShiftModifier,
+    ctrl=Qt.KeyboardModifier.ControlModifier,
+    alt=Qt.KeyboardModifier.AltModifier,
+    meta=Qt.KeyboardModifier.MetaModifier,
+    keypad=Qt.KeyboardModifier.KeypadModifier,
+    group_switch=Qt.KeyboardModifier.GroupSwitchModifier,
+)
+
 OrientationStr = Literal["horizontal", "vertical"]
 ORIENTATION: bidict[OrientationStr, Qt.Orientation] = bidict(
     horizontal=Orientation.Horizontal, vertical=Orientation.Vertical
@@ -187,16 +206,16 @@ STATE: bidict[StateStr, Qt.CheckState] = bidict(
 )
 
 MATCH_FLAGS = dict(
-    exact=Qt.MatchExactly,
-    fixed_string=Qt.MatchFixedString,
-    contains=Qt.MatchContains,
-    starts_with=Qt.MatchStartsWith,
-    ends_with=Qt.MatchEndsWith,
-    case_sensitive=Qt.MatchCaseSensitive,
-    regex=Qt.MatchRegularExpression,
-    wildcard=Qt.MatchWildcard,
-    wrap=Qt.MatchWrap,
-    recursive=Qt.MatchRecursive,
+    exact=Qt.MatchFlag.MatchExactly,
+    fixed_string=Qt.MatchFlag.MatchFixedString,
+    contains=Qt.MatchFlag.MatchContains,
+    starts_with=Qt.MatchFlag.MatchStartsWith,
+    ends_with=Qt.MatchFlag.MatchEndsWith,
+    case_sensitive=Qt.MatchFlag.MatchCaseSensitive,
+    regex=Qt.MatchFlag.MatchRegularExpression,
+    wildcard=Qt.MatchFlag.MatchWildcard,
+    wrap=Qt.MatchFlag.MatchWrap,
+    recursive=Qt.MatchFlag.MatchRecursive,
 )
 
 MatchFlagStr = Literal[
@@ -212,9 +231,16 @@ MatchFlagStr = Literal[
     "recursive",
 ]
 
+ImageConversionFlagStr = Literal["auto", "color_only", "mono_only"]
+IMAGE_CONVERSION_FLAGS: bidict[ImageConversionFlagStr, Qt.ImageConversionFlag] = bidict(
+    auto=Qt.ImageConversionFlag.AutoColor,
+    color_only=Qt.ImageConversionFlag.ColorOnly,
+    mono_only=Qt.ImageConversionFlag.MonoOnly,
+)
+
 FilterModeStr = Literal["starts_with", "contains", "ends_with"]
 FILTER_MODES = mappers.FlagMap(
-    Qt.MatchFlags,
+    Qt.MatchFlag,
     starts_with=Qt.MatchFlag.MatchStartsWith,
     contains=Qt.MatchFlag.MatchContains,
     ends_with=Qt.MatchFlag.MatchEndsWith,
@@ -239,7 +265,7 @@ DOCK_POSITION: bidict[DockPositionStr, Qt.DockWidgetArea] = bidict(
 )
 
 DockPositionsStr = Literal["top", "bottom", "left", "right", "all"]
-DOCK_POSITIONS: bidict[DockPositionsStr, Qt.DockWidgetAreas] = bidict(
+DOCK_POSITIONS: bidict[DockPositionsStr, Qt.DockWidgetArea] = bidict(
     top=Qt.DockWidgetArea.TopDockWidgetArea,
     bottom=Qt.DockWidgetArea.BottomDockWidgetArea,
     left=Qt.DockWidgetArea.LeftDockWidgetArea,
@@ -304,7 +330,7 @@ CursorShapeStr = Literal[
     "wait",
     "caret",
     "size_vertical",
-    "size_horizonal",
+    "size_horizontal",
     "size_topright",
     "size_topleft",
     "size_all",
@@ -329,7 +355,7 @@ CURSOR_SHAPE: bidict[CursorShapeStr, Qt.CursorShape] = bidict(
     wait=Qt.CursorShape.WaitCursor,
     caret=Qt.CursorShape.IBeamCursor,
     size_vertical=Qt.CursorShape.SizeVerCursor,
-    size_horizonal=Qt.CursorShape.SizeHorCursor,
+    size_horizontal=Qt.CursorShape.SizeHorCursor,
     size_topright=Qt.CursorShape.SizeBDiagCursor,
     size_topleft=Qt.CursorShape.SizeFDiagCursor,
     size_all=Qt.CursorShape.SizeAllCursor,
@@ -555,12 +581,13 @@ GESTURE_TYPE: bidict[GestureTypeStr, Qt.GestureType] = bidict(
 
 GestureStateStr = Literal["none", "started", "updated", "finished", "canceled"]
 GESTURE_STATE: bidict[GestureStateStr, Qt.GestureState] = bidict(
-    none=Qt.GestureState(0),  # type: ignore # GestureState.NoGesture
     started=Qt.GestureState.GestureStarted,
     updated=Qt.GestureState.GestureUpdated,
     finished=Qt.GestureState.GestureFinished,
     canceled=Qt.GestureState.GestureCanceled,
 )
+if prettyqt.qt.API != "pyqt6":
+    GESTURE_STATE["none"] = Qt.GestureState(0)  # type: ignore
 
 ScrollBarPolicyStr = Literal["always_on", "always_off", "as_needed"]
 SCROLLBAR_POLICY: bidict[ScrollBarPolicyStr, Qt.ScrollBarPolicy] = bidict(
@@ -610,12 +637,12 @@ WINDOW_FLAGS: bidict[WindowFlagStr, Qt.WindowType] = bidict(
 
 WindowStateStr = Literal["none", "minimized", "maximized", "fullscreen", "active"]
 WINDOW_STATES = mappers.FlagMap(
-    Qt.WindowStates,
-    none=Qt.WindowNoState,
-    minimized=Qt.WindowMinimized,
-    maximized=Qt.WindowMaximized,
-    fullscreen=Qt.WindowFullScreen,
-    active=Qt.WindowActive,
+    Qt.WindowState,
+    none=Qt.WindowState.WindowNoState,
+    minimized=Qt.WindowState.WindowMinimized,
+    maximized=Qt.WindowState.WindowMaximized,
+    fullscreen=Qt.WindowState.WindowFullScreen,
+    active=Qt.WindowState.WindowActive,
 )
 
 FillRuleStr = Literal["odd_even", "winding"]
@@ -840,3 +867,67 @@ WIDGET_ATTRIBUTE: bidict[WidgetAttributeStr, Qt.WidgetAttribute] = bidict(
     always_stack_on_top=Attr.WA_AlwaysStackOnTop,
     contents_margins_respects_safe_area=Attr.WA_ContentsMarginsRespectsSafeArea,
 )
+
+ApplicationAttributeStr = Literal[
+    "dont_show_icons_in_menus",
+    "dont_show_shortcuts_in_context_menus",
+    "native_windows",
+    "dont_create_native_widget_siblings",
+    "plugin_application",
+    "dont_use_native_menu_bar",
+    "mac_dont_swap_ctrl_and_meta",
+    "use_96_dpi",
+    "synthesize_touch_for_mouse_events",
+    "synthesize_touch_for_touch_events",
+    "use_high_dpi_pixmaps",
+    "force_raster_widgets",
+    "use_desktop_open_gl",
+    "use_open_gl_es",
+    "use_software_open_gl",
+    "share_open_gl_contexts",
+    "set_palette",
+    "enable_high_dpi_scaling",
+    "disable_high_dpi_scaling",
+    "use_style_sheet_propagation_in_styles",
+    "dont_use_native_dialogs",
+    "synthesize_mouse_for_tablet_events",
+    "compress_tablet_events",
+    "dont_check_open_gl_context_thread",
+    "disable_shader_disk_cache",
+    "disable_window_context_help_button",
+    "disable_session_manager",
+    "disable_native_virtual_keyboard",
+]
+
+Att = Qt.ApplicationAttribute
+
+APPLICATION_ATTRIBUTE: bidict[ApplicationAttributeStr, Qt.ApplicationAttribute] = bidict(
+    dont_show_icons_in_menus=Att.AA_DontShowIconsInMenus,
+    dont_show_shortcuts_in_context_menus=Att.AA_DontShowShortcutsInContextMenus,
+    native_windows=Att.AA_NativeWindows,
+    dont_create_native_widget_siblings=Att.AA_DontCreateNativeWidgetSiblings,
+    plugin_application=Att.AA_PluginApplication,
+    dont_use_native_menu_bar=Att.AA_DontUseNativeMenuBar,
+    mac_dont_swap_ctrl_and_meta=Att.AA_MacDontSwapCtrlAndMeta,
+    use_96_dpi=Att.AA_Use96Dpi,
+    synthesize_touch_for_mouse_events=Att.AA_SynthesizeTouchForUnhandledMouseEvents,
+    synthesize_touch_for_touch_events=Att.AA_SynthesizeMouseForUnhandledTouchEvents,
+    # use_high_dpi_pixmaps=Att.AA_UseHighDpiPixmaps, # not available on PyQt6
+    force_raster_widgets=Att.AA_ForceRasterWidgets,
+    use_desktop_open_gl=Att.AA_UseDesktopOpenGL,
+    use_open_gl_es=Att.AA_UseOpenGLES,
+    use_software_open_gl=Att.AA_UseSoftwareOpenGL,
+    share_open_gl_contexts=Att.AA_ShareOpenGLContexts,
+    set_palette=Att.AA_SetPalette,
+    # enable_high_dpi_scaling=Att.AA_EnableHighDpiScaling, # not available on PyQt6
+    # disable_high_dpi_scaling=Att.AA_DisableHighDpiScaling, # not available on PyQt6
+    use_style_sheet_propagation_in_styles=Att.AA_UseStyleSheetPropagationInWidgetStyles,
+    dont_use_native_dialogs=Att.AA_DontUseNativeDialogs,
+    synthesize_mouse_for_tablet_events=Att.AA_SynthesizeMouseForUnhandledTabletEvents,
+    compress_tablet_events=Att.AA_CompressTabletEvents,
+    dont_check_open_gl_context_thread=Att.AA_DontCheckOpenGLContextThreadAffinity,
+    disable_shader_disk_cache=Att.AA_DisableShaderDiskCache,
+    # disable_window_context_help_button=Att.AA_DisableWindowContextHelpButton,
+    disable_session_manager=Att.AA_DisableSessionManager,
+    disable_native_virtual_keyboard=Att.AA_DisableNativeVirtualKeyboard,
+)
