@@ -1,31 +1,31 @@
 from __future__ import annotations
 
-from typing import Literal, Union
+from typing import Literal
 
 from prettyqt import core
 from prettyqt.qt import QtCore
-from prettyqt.utils import InvalidParamError, bidict
+from prettyqt.utils import InvalidParamError, bidict, types
 
 
 FLOATING_POINT_PRECISION = bidict(
-    single=QtCore.QDataStream.SinglePrecision,
-    double=QtCore.QDataStream.DoublePrecision,
+    single=QtCore.QDataStream.FloatingPointPrecision.SinglePrecision,
+    double=QtCore.QDataStream.FloatingPointPrecision.DoublePrecision,
 )
 
 FloatingPointPrecisionStr = Literal["single", "double"]
 
 BYTE_ORDER = bidict(
-    big_endian=QtCore.QDataStream.BigEndian,
-    little_endian=QtCore.QDataStream.LittleEndian,
+    big_endian=QtCore.QDataStream.ByteOrder.BigEndian,
+    little_endian=QtCore.QDataStream.ByteOrder.LittleEndian,
 )
 
 ByteOrderStr = Literal["big_endian", "little_endian"]
 
 STATUS = bidict(
-    ok=QtCore.QDataStream.Ok,
-    read_past_end=QtCore.QDataStream.ReadPastEnd,
-    read_corrupt_data=QtCore.QDataStream.ReadCorruptData,
-    write_failed=QtCore.QDataStream.WriteFailed,
+    ok=QtCore.QDataStream.Status.Ok,
+    read_past_end=QtCore.QDataStream.Status.ReadPastEnd,
+    read_corrupt_data=QtCore.QDataStream.Status.ReadCorruptData,
+    write_failed=QtCore.QDataStream.Status.WriteFailed,
 )
 
 StatusStr = Literal["ok", "read_past_end", "read_corrupt_data", "write_failed"]
@@ -96,14 +96,16 @@ class DataStream(QtCore.QDataStream):
         return FLOATING_POINT_PRECISION.inverse[self.floatingPointPrecision()]
 
     @classmethod
-    def create_bytearray(cls, data) -> QtCore.QByteArray:
+    def create_bytearray(cls, data: types.QtSerializableType) -> QtCore.QByteArray:
         ba = QtCore.QByteArray()
         stream = cls(ba, core.iodevice.OPEN_MODES["write_only"])
         stream << data
         return ba
 
     @classmethod
-    def write_bytearray(cls, ba: Union[QtCore.QByteArray, bytes], write_to):
+    def write_bytearray(
+        cls, ba: QtCore.QByteArray | bytes, write_to: types.QtSerializableType
+    ):
         if not isinstance(ba, QtCore.QByteArray):
             ba = QtCore.QByteArray(ba)
         stream = cls(ba, core.iodevice.OPEN_MODES["read_only"])
