@@ -2,7 +2,6 @@ from __future__ import annotations
 
 import os
 import pathlib
-from typing import List, Union
 
 from prettyqt import core
 from prettyqt.qt import QtCore
@@ -16,17 +15,17 @@ class FileSystemWatcher(QtCore.QFileSystemWatcher):
         paths = [str(p) for p in self.get_paths()]
         return f"{type(self).__name__}({paths})"
 
-    def get_directories(self) -> List[pathlib.Path]:
+    def get_directories(self) -> list[pathlib.Path]:
         return [pathlib.Path(p) for p in self.directories()]
 
-    def get_files(self) -> List[pathlib.Path]:
+    def get_files(self) -> list[pathlib.Path]:
         return [pathlib.Path(p) for p in self.files()]
 
-    def get_paths(self) -> List[pathlib.Path]:
+    def get_paths(self) -> list[pathlib.Path]:
         return self.get_directories() + self.get_files()
 
-    def add_path(self, path: Union[str, os.PathLike]) -> bool:
+    def add_path(self, path: str | os.PathLike) -> bool:
         return self.addPath(os.fspath(path))
 
-    def add_paths(self, paths: List[Union[str, os.PathLike]]):
+    def add_paths(self, paths: list[str | os.PathLike]):
         self.addPaths([os.fspath(p) for p in paths])
