@@ -2,24 +2,24 @@ from __future__ import annotations
 
 import contextlib
 import os
-from typing import Literal, Union
+from typing import Literal
 
 from prettyqt.qt import QtCore
 from prettyqt.utils import bidict
 
 
 LOCK_ERROR = bidict(
-    none=QtCore.QLockFile.NoError,
-    lock_failed=QtCore.QLockFile.LockFailedError,
-    permission=QtCore.QLockFile.PermissionError,
-    unknown=QtCore.QLockFile.UnknownError,
+    none=QtCore.QLockFile.LockError.NoError,
+    lock_failed=QtCore.QLockFile.LockError.LockFailedError,
+    permission=QtCore.QLockFile.LockError.PermissionError,
+    unknown=QtCore.QLockFile.LockError.UnknownError,
 )
 
 LockErrorStr = Literal["none", "lock_failed", "permission", "unknown"]
 
 
 class LockFile(QtCore.QLockFile):
-    def __init__(self, path: Union[str, os.PathLike]):
+    def __init__(self, path: str | os.PathLike):
         super().__init__(os.fspath(path))
 
     def get_error(self) -> LockErrorStr:
