@@ -1,49 +1,51 @@
 from __future__ import annotations
 
-from typing import Callable, Dict, Iterator, Literal, Optional, Tuple, Union
+from typing import Callable, Iterator, Literal
 
 from prettyqt import core
 from prettyqt.qt import QtCore
 from prettyqt.utils import bidict
 
 
+mod = QtCore.QRegularExpression
+
 FLAGS = bidict(
-    none=QtCore.QRegularExpression.NoPatternOption,
-    ignorecase=QtCore.QRegularExpression.CaseInsensitiveOption,
-    dotall=QtCore.QRegularExpression.DotMatchesEverythingOption,
-    multiline=QtCore.QRegularExpression.MultilineOption,
-    verbose=QtCore.QRegularExpression.ExtendedPatternSyntaxOption,
-    inverted_greedyness=QtCore.QRegularExpression.InvertedGreedinessOption,
-    dont_capture=QtCore.QRegularExpression.DontCaptureOption,
-    unicode=QtCore.QRegularExpression.UseUnicodePropertiesOption,
+    none=mod.PatternOption.NoPatternOption,
+    ignorecase=mod.PatternOption.CaseInsensitiveOption,
+    dotall=mod.PatternOption.DotMatchesEverythingOption,
+    multiline=mod.PatternOption.MultilineOption,
+    verbose=mod.PatternOption.ExtendedPatternSyntaxOption,
+    inverted_greedyness=mod.PatternOption.InvertedGreedinessOption,
+    dont_capture=mod.PatternOption.DontCaptureOption,
+    unicode=mod.PatternOption.UseUnicodePropertiesOption,
 )
 
 MATCH_TYPE = bidict(
-    normal=QtCore.QRegularExpression.NormalMatch,
-    prefer_complete=QtCore.QRegularExpression.PartialPreferCompleteMatch,
-    prefer_first=QtCore.QRegularExpression.PartialPreferFirstMatch,
-    no_match=QtCore.QRegularExpression.NoMatch,
+    normal=mod.MatchType.NormalMatch,
+    prefer_complete=mod.MatchType.PartialPreferCompleteMatch,
+    prefer_first=mod.MatchType.PartialPreferFirstMatch,
+    no_match=mod.MatchType.NoMatch,
 )
 
 MatchTypeStr = Literal["normal", "prefer_complete", "prefer_first", "no_match"]
 
 MATCH_OPTIONS = bidict(
-    none=QtCore.QRegularExpression.NoMatchOption,
-    anchored=QtCore.QRegularExpression.AnchoredMatchOption,
+    none=mod.MatchOption.NoMatchOption,
+    anchored=mod.MatchOption.AnchorAtOffsetMatchOption,  # type: ignore
 )
 
 
 class RegularExpression(QtCore.QRegularExpression):
     def __init__(
         self,
-        pattern: Union[str, QtCore.QRegularExpression] = "",
+        pattern: str | QtCore.QRegularExpression = "",
         flags: QtCore.QRegularExpression.PatternOption = FLAGS["none"],
     ):
         if isinstance(pattern, QtCore.QRegularExpression):
             super().__init__(pattern)
         else:
             if isinstance(flags, int):
-                flags = core.RegularExpression.PatternOptions(flags)  # type: ignore
+                flags = core.RegularExpression.PatternOption(flags)  # type: ignore
             super().__init__(pattern, flags)  # type: ignore
 
     def __repr__(self):
@@ -70,7 +72,7 @@ class RegularExpression(QtCore.QRegularExpression):
         self,
         text: str,
         offset: int = 0,
-        match_type: Union[MatchTypeStr, QtCore.QRegularExpression.MatchType] = "normal",
+        match_type: MatchTypeStr | QtCore.QRegularExpression.MatchType = "normal",
         anchored: bool = False,
     ) -> core.RegularExpressionMatch:
         if isinstance(match_type, str):
@@ -85,8 +87,8 @@ class RegularExpression(QtCore.QRegularExpression):
         return core.RegularExpressionMatch(match)
 
     def fullmatch(
-        self, string: str, pos: int = 0, endpos: Optional[int] = None
-    ) -> Optional[core.RegularExpressionMatch]:
+        self, string: str, pos: int = 0, endpos: int | None = None
+    ) -> core.RegularExpressionMatch | None:
         if endpos:
             string = string[:endpos]
         match = super().match(string, pos)
@@ -96,7 +98,7 @@ class RegularExpression(QtCore.QRegularExpression):
             return None
 
     def finditer(
-        self, string: str, pos: int = 0, endpos: Optional[int] = None
+        self, string: str, pos: int = 0, endpos: int | None = None
     ) -> Iterator[core.RegularExpressionMatch]:
         for match in self.globalMatch(string[:endpos], offset=pos):
             match.pos = pos
@@ -104,13 +106,11 @@ class RegularExpression(QtCore.QRegularExpression):
             match.string = string
             yield match
 
-    def findall(self, string: str, pos: int = 0, endpos: Optional[int] = None) -> list:
+    def findall(self, string: str, pos: int = 0, endpos: int | None = None) -> list:
         matches = list(self.globalMatch(string[:endpos], offset=pos))
         return [m.groups() if len(m.groups()) > 1 else m.group(0) for m in matches]
 
-    def subn(
-        self, repl: Union[str, Callable], string: str, count: int = 0
-    ) -> Tuple[str, int]:
+    def subn(self, repl: str | Callable, string: str, count: int = 0) -> tuple[str, int]:
         result = string
         matches = self.global_match(string)
         matches = list(matches)
@@ -126,11 +126,11 @@ class RegularExpression(QtCore.QRegularExpression):
             result = result[: m.start()] + to_replace + result[m.end() :]
         return (result, min(len(matches), count))
 
-    def sub(self, repl: Union[str, Callable], string: str, count: int = 0) -> str:
+    def sub(self, repl: str | Callable, string: str, count: int = 0) -> str:
         res = self.subn(repl, string, count)
         return res[0]
 
-    def search(self, string: str, pos: int = 0, endpos: Optional[int] = None):
+    def search(self, string: str, pos: int = 0, endpos: int | None = None):
         match = super().match(string[:endpos], pos)
         return match if match.hasMatch() else None
 
@@ -172,7 +172,7 @@ class RegularExpression(QtCore.QRegularExpression):
         return self.captureCount()
 
     @property
-    def groupindex(self) -> Dict[str, int]:
+    def groupindex(self) -> dict[str, int]:
         return {k: i for i, k in enumerate(self.namedCaptureGroups()[1:], start=1)}
 
     @property
