@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Any, Dict
+from typing import Any
 
 from prettyqt.qt import QtCore
 
@@ -23,7 +23,7 @@ class UrlQuery(QtCore.QUrlQuery):
     def serialize_fields(self):
         return dict(path=self.toString())
 
-    def serialize(self) -> Dict[str, Any]:
+    def serialize(self) -> dict[str, Any]:
         return self.serialize_fields()
 
     # def add_query_items(self, **items: str):
