@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import List, Literal, Optional
+from typing import Literal
 
 from prettyqt import core, widgets
 from prettyqt.qt import QtCore, QtWidgets
@@ -12,18 +12,18 @@ SideStr = Literal["left", "top", "right", "bottom"]
 class SideGrip(widgets.Widget):
     def __init__(
         self,
-        parent: Optional[QtWidgets.QWidget],
+        parent: QtWidgets.QWidget | None,
         edge: SideStr,
     ):
         super().__init__(parent=parent)
         if edge == "left":
-            self.set_cursor("size_horizonal")
+            self.set_cursor("size_horizontal")
             self.resize_fn = self.resize_left
         elif edge == "top":
             self.set_cursor("size_vertical")
             self.resize_fn = self.resize_top
         elif edge == "right":
-            self.set_cursor("size_horizonal")
+            self.set_cursor("size_horizontal")
             self.resize_fn = self.resize_right
         else:
             self.set_cursor("size_vertical")
@@ -55,7 +55,7 @@ class SideGrip(widgets.Widget):
         window.resize(window.width(), height)
 
     def mousePressEvent(self, event):
-        if event.button() == QtCore.Qt.LeftButton:
+        if event.button() == QtCore.Qt.MouseButton.LeftButton:
             self.mouse_pos = event.pos()
 
     def mouseMoveEvent(self, event):
@@ -70,10 +70,10 @@ class SideGrip(widgets.Widget):
 class FramelessWindow(widgets.MainWindow):
     _grip_size = 4
 
-    def __init__(self, parent: Optional[QtWidgets.QWidget] = None):
+    def __init__(self, parent: QtWidgets.QWidget | None = None):
         super().__init__(parent=parent)
         self.set_flags(frameless=True)
-        sides: List[SideStr] = ["left", "top", "right", "bottom"]
+        sides: list[SideStr] = ["left", "top", "right", "bottom"]
         self.side_grips = [SideGrip(self, side) for side in sides]
         # corner grips should be "on top" of everything, otherwise the side grips
         # will take precedence on mouse events, so we are adding them *after*;
@@ -143,4 +143,4 @@ if __name__ == "__main__":
     m.set_widget(button)
     m.show()
     m.resize(240, 160)
-    app.exec_()
+    app.main_loop()
