@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import os
-from typing import Optional, Union
 
 from prettyqt import widgets
 from prettyqt.qt import QtWidgets
@@ -11,8 +10,8 @@ class ImageViewer(widgets.Widget):
     def __init__(
         self,
         title: str = "",
-        path: Union[os.PathLike, str] = None,
-        parent: Optional[QtWidgets.QWidget] = None,
+        path: os.PathLike | str | None = None,
+        parent: QtWidgets.QWidget | None = None,
     ):
         super().__init__(parent)
         if title:
