@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import Optional
-
 from prettyqt import core, widgets
 from prettyqt.qt import QtWidgets
 
@@ -11,7 +9,9 @@ class InputAndSlider(widgets.Widget):
     value_changed = core.Signal(int)
 
     def __init__(
-        self, bounds: Optional[tuple] = None, parent: Optional[QtWidgets.QWidget] = None
+        self,
+        bounds: tuple[int, int] | None = None,
+        parent: QtWidgets.QWidget | None = None,
     ):
         super().__init__(parent)
         self.path = None
