@@ -2,7 +2,7 @@
 
 from __future__ import annotations
 
-from typing import Optional, Sequence
+from typing import Sequence
 
 from prettyqt import constants, core, gui, widgets
 from prettyqt.qt import QtWidgets
@@ -16,7 +16,7 @@ class LabeledSlider(widgets.Widget):
         self,
         labels: Sequence[str],
         orientation: constants.OrientationStr = "horizontal",
-        parent: Optional[QtWidgets.QWidget] = None,
+        parent: QtWidgets.QWidget | None = None,
     ):
         super().__init__(parent=parent)
 
@@ -56,9 +56,11 @@ class LabeledSlider(widgets.Widget):
         st_slider.initFrom(self.sl)
         st_slider.orientation = self.sl.orientation()
 
-        length = style.pixelMetric(widgets.Style.PM_SliderLength, st_slider, self.sl)
+        length = style.pixelMetric(
+            widgets.Style.PixelMetric.PM_SliderLength, st_slider, self.sl
+        )
         available = style.pixelMetric(
-            widgets.Style.PM_SliderSpaceAvailable, st_slider, self.sl
+            widgets.Style.PixelMetric.PM_SliderSpaceAvailable, st_slider, self.sl
         )
 
         painter = gui.Painter(self)
