@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Optional, Pattern, Union
+from typing import Pattern
 
 import regex as re
 
@@ -25,7 +25,7 @@ class RegexInput(widgets.Widget):
         self,
         show_flags: bool = True,
         show_error: bool = True,
-        parent: Optional[QtWidgets.QWidget] = None,
+        parent: QtWidgets.QWidget | None = None,
     ):
         super().__init__(parent=parent)
         self.set_layout("grid")
@@ -35,7 +35,8 @@ class RegexInput(widgets.Widget):
             "Flags", icon="mdi.flag-variant-outline"
         )
         self.label_error = widgets.Label()
-        self.label_error.set_color("red")
+        error_color = self.get_palette().get_color("highlight")
+        self.label_error.set_color(error_color)
         self.box[0, 0:1] = self.lineedit
         if show_flags:
             self.box[0, 2] = self.tb_flags
@@ -80,13 +81,13 @@ class RegexInput(widgets.Widget):
         for identifier, flag in MAP.items():
             self.tb_flags[identifier] = bool(value & flag)
 
-    def set_value(self, value: Optional[Union[str, Pattern]]):
+    def set_value(self, value: str | Pattern | None):
         if value is None:
             self.pattern = ""
-            self.flags = 0
+            self.compile_flags = 0
         elif isinstance(value, str):
             self.pattern = value
-            self.flags = 0
+            self.compile_flags = 0
         else:
             self.pattern = value.pattern
             self.compile_flags = value.flags
