@@ -4,7 +4,7 @@
 
 from __future__ import annotations
 
-from typing import Literal, Optional, Tuple
+from typing import Literal
 
 from prettyqt import core, gui, widgets
 from prettyqt.qt import QtCore, QtWidgets
@@ -29,9 +29,9 @@ from prettyqt.utils import colors, types
 # THE SOFTWARE.
 
 
-SLIDER_STYLE = widgets.Style.CC_Slider
-HANDLE_STYLE = widgets.Style.SC_SliderHandle
-GROOVE_STYLE = widgets.Style.SC_SliderGroove
+SLIDER_STYLE = widgets.Style.ComplexControl.CC_Slider
+HANDLE_STYLE = widgets.Style.SubControl.SC_SliderHandle
+GROOVE_STYLE = widgets.Style.SubControl.SC_SliderGroove
 
 
 MOVEMENT_MODE = ["no_crossing", "no_overlap", "free"]
@@ -55,7 +55,7 @@ class SpanSlider(widgets.Slider):
     upper_pos_changed = core.Signal(float)
     slider_pressed = core.Signal(object)
 
-    def __init__(self, parent: Optional[QtWidgets.QWidget] = None):
+    def __init__(self, parent: QtWidgets.QWidget | None = None):
         super().__init__("horizontal", parent)
         self.rangeChanged.connect(self.update_range)
         self.sliderReleased.connect(self._move_pressed_handle)
@@ -66,14 +66,14 @@ class SpanSlider(widgets.Slider):
         self.upper_pos = 0.0
         self.offset = 0
         self.position = 0.0
-        self.last_pressed: Optional[str] = None
-        self.upper_pressed = widgets.Style.SC_None
-        self.lower_pressed = widgets.Style.SC_None
+        self.last_pressed: str | None = None
+        self.upper_pressed = widgets.Style.SubControl.SC_None
+        self.lower_pressed = widgets.Style.SubControl.SC_None
         self.movement: MovementModeStr = "no_crossing"
         self._main_control: Literal["lower", "upper"] = "lower"
         self._first_movement = False
         self._block_tracking = False
-        dark_color = self.palette().color(gui.Palette.Dark)
+        dark_color = self.palette().color(gui.Palette.ColorRole.Dark)
         self.gradient_left = dark_color.lighter(110)
         self.gradient_right = dark_color.lighter(110)
 
@@ -100,7 +100,9 @@ class SpanSlider(widgets.Slider):
 
         opt = widgets.StyleOptionSlider()
         self.initStyleOption(opt)
-        m = self.style().pixelMetric(widgets.Style.PM_MaximumDragDistance, opt, self)
+        m = self.style().pixelMetric(
+            widgets.Style.PixelMetric.PM_MaximumDragDistance, opt, self
+        )
         pixel_pos = self.pick(event.pos()) - self.offset
         new_pos = float(self._pixel_pos_to_value(pixel_pos))
         if m >= 0:
@@ -144,7 +146,7 @@ class SpanSlider(widgets.Slider):
     def mouseReleaseEvent(self, event):
         super().mouseReleaseEvent(event)
         self.setSliderDown(False)
-        self.lower_pressed = self.upper_pressed = widgets.Style.SC_None
+        self.lower_pressed = self.upper_pressed = widgets.Style.SubControl.SC_None
         self.update()
 
     def paintEvent(self, event):
@@ -153,7 +155,7 @@ class SpanSlider(widgets.Slider):
         # ticks
         opt = widgets.StyleOptionSlider()
         self.initStyleOption(opt)
-        opt.subControls = widgets.Style.SC_SliderTickmarks
+        opt.subControls = widgets.Style.SubControl.SC_SliderTickmarks
         painter.draw_complex_control("slider", opt)
 
         # groove
@@ -205,10 +207,10 @@ class SpanSlider(widgets.Slider):
     def on_value_change(self):
         self.value_changed.emit(self.lower_val, self.upper_val)
 
-    def get_value(self) -> Tuple[float, float]:
+    def get_value(self) -> tuple[float, float]:
         return (self.lower_val, self.upper_val)
 
-    def set_value(self, value: Tuple[float, float]):
+    def set_value(self, value: tuple[float, float]):
         self.set_lower_value(value[0])
         self.set_upper_value(value[1])
 
@@ -358,13 +360,13 @@ class SpanSlider(widgets.Slider):
     def _setup_painter(
         self,
         painter: widgets.StylePainter,
-        orientation: str,
+        orientation: Literal["horizontal", "vertical"],
         x1: int,
         y1: int,
         x2: int,
         y2: int,
     ):
-        highlight = self.palette().color(gui.Palette.Highlight)
+        highlight = self.palette().color(gui.Palette.ColorRole.Highlight)
         gradient = gui.LinearGradient(x1, y1, x2, y2)
         gradient[0] = highlight.darker(120)
         gradient[1] = highlight.lighter(108)
@@ -415,7 +417,7 @@ class SpanSlider(widgets.Slider):
 
         if pressed == HANDLE_STYLE:
             opt.activeSubControls = pressed
-            opt.state |= widgets.Style.State_Sunken
+            opt.state |= widgets.Style.StateFlag.State_Sunken
         painter.draw_complex_control("slider", opt)
 
     def get_style_option(self, handle: HandleStr) -> widgets.StyleOptionSlider:
@@ -470,7 +472,7 @@ class SpanSlider(widgets.Slider):
 
 
 class SpanSliderWidget(widgets.Widget):
-    def __init__(self, parent: Optional[QtWidgets.QWidget] = None):
+    def __init__(self, parent: QtWidgets.QWidget | None = None):
         super().__init__(parent=parent)
         self.set_layout("grid")
         self.slider = SpanSlider()
