@@ -28,7 +28,6 @@ SOFTWARE.
 from __future__ import annotations
 
 import math
-from typing import Optional
 
 from prettyqt import constants, core, gui, widgets
 from prettyqt.qt import QtCore, QtWidgets
@@ -38,13 +37,13 @@ from prettyqt.utils import colors, types
 class BaseWaitingSpinner(widgets.Widget):
     def __init__(
         self,
-        parent: Optional[QtWidgets.QWidget],
+        parent: QtWidgets.QWidget | None,
         modality: constants.ModalityStr = "none",
     ):
         super().__init__(parent=parent)
 
         # WAS IN initialize()
-        self._color = gui.Color("black")
+        self._color = self.get_palette().get_color("text")
         self._roundness = 100.0
         self._minimum_trail_opacity = 3.14159265358979323846
         self._trail_fade_percentage = 80.0
@@ -85,7 +84,7 @@ class BaseWaitingSpinner(widgets.Widget):
                 distance = self.linecount_distance_from_primary(
                     i, self._current_counter, self._line_num
                 )
-                color = self.current_line_color(
+                color = self._current_line_color(
                     distance,
                     self._line_num,
                     self._trail_fade_percentage,
@@ -193,7 +192,7 @@ class BaseWaitingSpinner(widgets.Widget):
             distance += total_lines
         return distance
 
-    def current_line_color(
+    def _current_line_color(
         self,
         count_distance: int,
         total_lines: int,
@@ -222,7 +221,7 @@ class BaseWaitingSpinner(widgets.Widget):
 class WaitingSpinner(BaseWaitingSpinner):
     def __init__(
         self,
-        parent: Optional[QtWidgets.QWidget],
+        parent: QtWidgets.QWidget | None,
         center_on_parent: bool = True,
         disable_parent: bool = True,
         modality: constants.ModalityStr = "none",
@@ -263,6 +262,7 @@ class WaitingSpinner(BaseWaitingSpinner):
 
 if __name__ == "__main__":
     app = widgets.app()
+    # app.set_theme("dark")
     mainwindow = widgets.MainWindow()
     spinner = WaitingSpinner(mainwindow)
     mainwindow.show()
