@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import Tuple
-
 from prettyqt import core, gui
 from prettyqt.qt import QtGui
 
@@ -16,19 +14,32 @@ class Image(QtGui.QImage):
     def __setstate__(self, ba):
         core.DataStream.write_bytearray(ba, self)
 
-    def __setitem__(self, index: Tuple[int, int], value):
+    def __setitem__(self, index: tuple[int, int], value):
         self.setPixel(index[0], index[1], value)
 
     def __reduce__(self):
         return type(self), (), self.__getstate__()
 
-    def __getitem__(self, index: Tuple[int, int]):
+    def __getitem__(self, index: tuple[int, int]):
         return self.pixel(index[0], index[1])
 
     def __bytes__(self):
         ba = core.DataStream.create_bytearray(self)
         return bytes(ba)
 
+    @classmethod
+    def from_ndarray(cls, arr) -> Image:
+        import numpy as np
+
+        height, width, channel = arr.shape
+        if arr.dtype in {np.float32, np.float64}:
+            arr = (255 * arr).round()
+        arr = arr.astype(np.uint8)
+        return cls(arr.data, width, height, channel * width, cls.Format_RGB888)
+
+    def invert_pixels(self, invert_alpha: bool = False):
+        self.invertPixels(self.InvertRgba if invert_alpha else self.InvertRgb)
+
 
 if __name__ == "__main__":
     image = Image()
