@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import contextlib
-from typing import Iterator, List, Literal, Union
+from typing import Iterator, Literal
 
 from prettyqt import constants, core, gui
 from prettyqt.qt import QtCore, QtGui
@@ -9,17 +9,17 @@ from prettyqt.utils import InvalidParamError, bidict, colors, types
 
 
 COMPOSITION_MODE = bidict(
-    source_over=QtGui.QPainter.CompositionMode_SourceOver,
-    destination_over=QtGui.QPainter.CompositionMode_DestinationOver,
-    clear=QtGui.QPainter.CompositionMode_Clear,
-    source=QtGui.QPainter.CompositionMode_Source,
-    destination=QtGui.QPainter.CompositionMode_Destination,
-    source_in=QtGui.QPainter.CompositionMode_SourceIn,
-    destination_in=QtGui.QPainter.CompositionMode_DestinationIn,
-    source_out=QtGui.QPainter.CompositionMode_SourceOut,
-    destination_out=QtGui.QPainter.CompositionMode_DestinationOut,
-    source_atop=QtGui.QPainter.CompositionMode_SourceAtop,
-    destination_atop=QtGui.QPainter.CompositionMode_DestinationAtop,
+    source_over=QtGui.QPainter.CompositionMode.CompositionMode_SourceOver,
+    destination_over=QtGui.QPainter.CompositionMode.CompositionMode_DestinationOver,
+    clear=QtGui.QPainter.CompositionMode.CompositionMode_Clear,
+    source=QtGui.QPainter.CompositionMode.CompositionMode_Source,
+    destination=QtGui.QPainter.CompositionMode.CompositionMode_Destination,
+    source_in=QtGui.QPainter.CompositionMode.CompositionMode_SourceIn,
+    destination_in=QtGui.QPainter.CompositionMode.CompositionMode_DestinationIn,
+    source_out=QtGui.QPainter.CompositionMode.CompositionMode_SourceOut,
+    destination_out=QtGui.QPainter.CompositionMode.CompositionMode_DestinationOut,
+    source_atop=QtGui.QPainter.CompositionMode.CompositionMode_SourceAtop,
+    destination_atop=QtGui.QPainter.CompositionMode.CompositionMode_DestinationAtop,
 )
 
 CompositionModeStr = Literal[
@@ -37,10 +37,10 @@ CompositionModeStr = Literal[
 ]
 
 RENDER_HINTS = bidict(
-    antialiasing=QtGui.QPainter.Antialiasing,
-    text_antialiasing=QtGui.QPainter.TextAntialiasing,
-    smooth_pixmap_transform=QtGui.QPainter.SmoothPixmapTransform,
-    lossless_image_rendering=QtGui.QPainter.LosslessImageRendering,
+    antialiasing=QtGui.QPainter.RenderHint.Antialiasing,
+    text_antialiasing=QtGui.QPainter.RenderHint.TextAntialiasing,
+    smooth_pixmap_transform=QtGui.QPainter.RenderHint.SmoothPixmapTransform,
+    lossless_image_rendering=QtGui.QPainter.RenderHint.LosslessImageRendering,
 )
 
 RenderHintStr = Literal[
@@ -84,7 +84,7 @@ class Painter(QtGui.QPainter):
 
     def draw_image(
         self,
-        target: Union[QtCore.QPoint, QtCore.QPointF, QtCore.QRect, QtCore.QRectF],
+        target: QtCore.QPoint | QtCore.QPointF | QtCore.QRect | QtCore.QRectF,
         frame_buffer: QtGui.QImage,
     ):
         self.set_composition_mode("source_atop")
@@ -92,9 +92,9 @@ class Painter(QtGui.QPainter):
 
     def draw_polygon(
         self,
-        points: Union[
-            QtGui.QPolygon, QtGui.QPolygonF, List[QtCore.QPoint], List[QtCore.QPointF]
-        ],
+        points: (
+            QtGui.QPolygon | QtGui.QPolygonF | list[QtCore.QPoint] | list[QtCore.QPointF]
+        ),
         fill_rule: constants.FillRuleStr = "odd_even",
     ):
         if fill_rule not in constants.FILL_RULE:
@@ -102,11 +102,11 @@ class Painter(QtGui.QPainter):
         self.drawPolygon(points, fillRule=constants.FILL_RULE[fill_rule])  # type: ignore
 
     def use_antialiasing(self):
-        self.setRenderHint(self.Antialiasing, True)
+        self.setRenderHint(self.RenderHint.Antialiasing, True)
 
     def fill_rect(
         self,
-        rect: Union[QtCore.QRectF, QtCore.QRect],
+        rect: QtCore.QRectF | QtCore.QRect,
         color: types.ColorType,
         pattern: constants.PatternStr = "solid",
     ):
@@ -121,26 +121,36 @@ class Painter(QtGui.QPainter):
 
     def set_pen(
         self,
-        style: constants.PenStyleStr = "solid",
+        style: constants.PenStyleStr | None = "solid",
         width: float = 1.0,
         color: types.ColorType = "black",
+        brush: QtGui.QBrush | None = None,
+        miter_limit: float = 2.0,
         join_style: constants.JoinStyleStr = "bevel",
         cap_style: constants.CapStyleStr = "square",
     ) -> gui.Pen:
         """Set pen to use.
 
         Args:
-            style: pen style to use
+            style: pen style
             width: pen width
             color: pen color
-            join_style: pen join style to use
-            cap_style: pen cap style to use
+            brush: pen brush
+            miter_limit: miter limit
+            join_style: pen join style
+            cap_style: pen cap style
         """
         pen = gui.Pen()
         pen.set_style(style)
+        if style in ["none", None]:
+            self.setPen(pen)
+            return pen
         pen.set_cap_style(cap_style)
         pen.set_join_style(join_style)
+        pen.setMiterLimit(miter_limit)
         pen.setWidthF(width)
+        if brush is not None:
+            pen.setBrush(brush)
         pen.set_color(color)
         self.setPen(pen)
         return pen
@@ -157,7 +167,7 @@ class Painter(QtGui.QPainter):
         color = colors.get_color(color)
         self.setPen(color)
 
-    def set_brush(self, brush: Union[QtGui.QBrush, types.ColorType]):
+    def set_brush(self, brush: QtGui.QBrush | types.ColorType):
         if not isinstance(brush, QtGui.QBrush):
             brush = colors.get_color(brush)
         self.setBrush(brush)
@@ -195,7 +205,9 @@ class Painter(QtGui.QPainter):
         self.setClipPath(path, constants.CLIP_OPERATION[operation])
 
     def get_text_rect(self, text: str) -> core.Rect:
-        return self.drawText(core.Rect(), QtCore.Qt.TextDontPrint, text)  # type: ignore
+        return self.drawText(
+            core.Rect(), QtCore.Qt.TextFlag.TextDontPrint, text
+        )  # type: ignore
 
     @contextlib.contextmanager
     def clip_path(
