@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import List
-
 from prettyqt import constants, core, gui
 from prettyqt.qt import QtGui
 from prettyqt.utils import InvalidParamError
@@ -64,10 +62,13 @@ class Screen:
             constants.SCREEN_ORIENTATION[orientation_2],
         )
 
-    def grab_window(self, *args, **kwargs) -> gui.Pixmap:
-        return gui.Pixmap(self.grabWindow(*args, **kwargs))
+    def grab_window(
+        self, window: int = 0, x: int = 0, y: int = 0, width: int = -1, height: int = -1
+    ) -> gui.Pixmap:
+        px = self.grabWindow(window, x, y, width, height)
+        return gui.Pixmap(px)
 
-    def get_virtual_siblings(self) -> List[Screen]:
+    def get_virtual_siblings(self) -> list[Screen]:
         return [Screen(i) for i in self.virtualSiblings()]
 
     # def serialize_fields(self):
