@@ -1,7 +1,12 @@
 from __future__ import annotations
 
+import contextlib
 import os
-from typing import Iterator, Literal, Union
+import pathlib
+from typing import Iterator, Literal
+
+import qstylizer.parser
+import qstylizer.style
 
 from prettyqt import constants, core, gui
 from prettyqt.qt import QtGui
@@ -10,36 +15,36 @@ from prettyqt.utils import InvalidParamError, bidict
 
 if core.VersionNumber.get_qt_version() >= (5, 14, 0):
     MARKDOWN_FEATURES = bidict(
-        no_html=QtGui.QTextDocument.MarkdownNoHTML,
-        commonmark=QtGui.QTextDocument.MarkdownDialectCommonMark,
-        github=QtGui.QTextDocument.MarkdownDialectGitHub,
+        no_html=QtGui.QTextDocument.MarkdownFeature.MarkdownNoHTML,
+        commonmark=QtGui.QTextDocument.MarkdownFeature.MarkdownDialectCommonMark,
+        github=QtGui.QTextDocument.MarkdownFeature.MarkdownDialectGitHub,
     )
 
 MarkdownFeatureStr = Literal["no_html", "commonmark", "github"]
 
 RESOURCE_TYPES = bidict(
-    unknown=QtGui.QTextDocument.UnknownResource,
-    html=QtGui.QTextDocument.HtmlResource,
-    image=QtGui.QTextDocument.ImageResource,
-    stylesheet=QtGui.QTextDocument.StyleSheetResource,
-    markdown=QtGui.QTextDocument.MarkdownResource,
-    user=QtGui.QTextDocument.UserResource,
+    unknown=QtGui.QTextDocument.ResourceType.UnknownResource,
+    html=QtGui.QTextDocument.ResourceType.HtmlResource,
+    image=QtGui.QTextDocument.ResourceType.ImageResource,
+    stylesheet=QtGui.QTextDocument.ResourceType.StyleSheetResource,
+    markdown=QtGui.QTextDocument.ResourceType.MarkdownResource,
+    user=QtGui.QTextDocument.ResourceType.UserResource,
 )
 
 ResourceTypeStr = Literal["unknown", "html", "image", "stylesheet", "markdown", "user"]
 
 STACKS = bidict(
-    undo=QtGui.QTextDocument.UndoStack,
-    redo=QtGui.QTextDocument.RedoStack,
-    undo_and_redo=QtGui.QTextDocument.UndoAndRedoStacks,
+    undo=QtGui.QTextDocument.Stacks.UndoStack,
+    redo=QtGui.QTextDocument.Stacks.RedoStack,
+    undo_and_redo=QtGui.QTextDocument.Stacks.UndoAndRedoStacks,
 )
 
 StackStr = Literal["undo", "redo", "undo_and_redo"]
 
 FIND_FLAGS = bidict(
-    backward=QtGui.QTextDocument.FindBackward,
-    case_sensitive=QtGui.QTextDocument.FindCaseSensitively,
-    whole_words=QtGui.QTextDocument.FindWholeWords,
+    backward=QtGui.QTextDocument.FindFlag.FindBackward,
+    case_sensitive=QtGui.QTextDocument.FindFlag.FindCaseSensitively,
+    whole_words=QtGui.QTextDocument.FindFlag.FindWholeWords,
 )
 
 FindFlagStr = Literal["backward", "case_sensitive", "whole_words"]
@@ -120,13 +125,31 @@ class TextDocument(QtGui.QTextDocument):
         return constants.CURSOR_MOVE_STYLE.inverse[self.defaultCursorMoveStyle()]
 
     def add_resource(
-        self, resource_type: ResourceTypeStr, name: Union[str, os.PathLike], resource
+        self, resource_type: ResourceTypeStr, name: str | os.PathLike, resource
     ):
         if resource_type not in RESOURCE_TYPES:
             raise InvalidParamError(resource_type, RESOURCE_TYPES)
         url = core.Url(name)
         self.addResource(RESOURCE_TYPES[resource_type], url, resource)
 
+    @contextlib.contextmanager
+    def edit_default_stylesheet(self) -> Iterator[qstylizer.style.StyleSheet]:
+        ss = self.get_default_stylesheet()
+        yield ss
+        self.set_default_stylesheet(ss)
+
+    def set_default_stylesheet(
+        self, ss: None | str | qstylizer.style.StyleSheet | os.PathLike
+    ):
+        if isinstance(ss, os.PathLike):
+            ss = pathlib.Path(ss).read_text()
+        elif ss is None:
+            ss = ""
+        self.setDefaultStyleSheet(str(ss))
+
+    def get_default_stylesheet(self) -> qstylizer.style.StyleSheet:
+        return qstylizer.parser.parse(self.defaultStyleSheet())
+
 
 if __name__ == "__main__":
     doc = TextDocument("This is a test\nHello")
