@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Literal, Union
+from typing import Literal
 
 from prettyqt import core, network
 from prettyqt.qt import QtCore, QtNetwork
@@ -8,12 +8,12 @@ from prettyqt.utils import InvalidParamError, bidict
 
 
 OPERATION = bidict(
-    head=QtNetwork.QNetworkAccessManager.HeadOperation,
-    get=QtNetwork.QNetworkAccessManager.GetOperation,
-    put=QtNetwork.QNetworkAccessManager.PutOperation,
-    post=QtNetwork.QNetworkAccessManager.PostOperation,
-    delete=QtNetwork.QNetworkAccessManager.DeleteOperation,
-    custom=QtNetwork.QNetworkAccessManager.CustomOperation,
+    head=QtNetwork.QNetworkAccessManager.Operation.HeadOperation,
+    get=QtNetwork.QNetworkAccessManager.Operation.GetOperation,
+    put=QtNetwork.QNetworkAccessManager.Operation.PutOperation,
+    post=QtNetwork.QNetworkAccessManager.Operation.PostOperation,
+    delete=QtNetwork.QNetworkAccessManager.Operation.DeleteOperation,
+    custom=QtNetwork.QNetworkAccessManager.Operation.CustomOperation,
 )
 
 OperationStr = Literal["head", "get", "put", "post", "delete", "custom"]
@@ -37,7 +37,7 @@ class NetworkAccessManager(QtNetwork.QNetworkAccessManager):
     #     if allow_redirects:
     #         pass
 
-    def get(self, request: Union[str, QtCore.QUrl, QtNetwork.QNetworkRequest]):
+    def get(self, request: str | QtCore.QUrl | QtNetwork.QNetworkRequest):
         if isinstance(request, str):
             request = core.Url(request)
         request = network.NetworkRequest(request)
