@@ -1,13 +1,15 @@
 from __future__ import annotations
 
 import functools
-from typing import Callable, Dict, Iterable, List, Optional, Tuple, Union
+from typing import Callable, Iterable, Literal, Sequence, Tuple, Union
 
 from prettyqt import core
-from prettyqt.prettyqtest.exceptions import TimeoutError
 from prettyqt.qt import QtCore
 
 
+SignalOrSignalTuple = Union[QtCore.Signal, Tuple[QtCore.Signal, str]]
+
+
 class _AbstractSignalBlocker:
     """Base class for :class:`SignalBlocker` and :class:`MultiSignalBlocker`.
 
@@ -26,7 +28,7 @@ class _AbstractSignalBlocker:
         self.signal_triggered = False
         self.raising = raising
         # will be initialized by inheriting implementations
-        self._signals: List[QtCore.Signal] = []
+        self._signals: list[QtCore.Signal] = []
         self._timeout_message = ""
         if timeout is None or timeout == 0:
             self._timer = None
@@ -86,23 +88,23 @@ class _AbstractSignalBlocker:
         return signal_name
 
     def _extract_signal_from_signal_tuple(self, potential_signal_tuple):
-        if isinstance(potential_signal_tuple, tuple):
-            if len(potential_signal_tuple) != 2:
-                raise ValueError(
-                    "Signal tuple must have length of 2 (first element is the signal, "
-                    "the second element is the signal's name)."
-                )
-            signal_tuple = potential_signal_tuple
-            signal_name = signal_tuple[1]
-            if not isinstance(signal_name, str):
-                raise TypeError(
-                    "Invalid type for provided signal name, "
-                    "expected str but got {}".format(type(signal_name))
-                )
-            if not signal_name:
-                raise ValueError("The provided signal name may not be empty")
-            return signal_name
-        return ""
+        if not isinstance(potential_signal_tuple, tuple):
+            return ""
+        if len(potential_signal_tuple) != 2:
+            raise ValueError(
+                "Signal tuple must have length of 2 (first element is the signal, "
+                "the second element is the signal's name)."
+            )
+        signal_tuple = potential_signal_tuple
+        signal_name = signal_tuple[1]
+        if not isinstance(signal_name, str):
+            raise TypeError(
+                "Invalid type for provided signal name, "
+                "expected str but got {}".format(type(signal_name))
+            )
+        if not signal_name:
+            raise ValueError("The provided signal name may not be empty")
+        return signal_name
 
     def determine_signal_name(self, potential_signal_tuple) -> str:
         """Attempts to determine the signal's name.
@@ -138,9 +140,7 @@ class _AbstractSignalBlocker:
                 return ""
 
     @staticmethod
-    def get_signal_from_potential_signal_tuple(
-        signal_tuple: Union[QtCore.Signal, Tuple[QtCore.Signal, str]]
-    ):
+    def get_signal_from_potential_signal_tuple(signal_tuple: SignalOrSignalTuple):
         if isinstance(signal_tuple, tuple):
             return signal_tuple[0]
         return signal_tuple
@@ -188,16 +188,16 @@ class SignalBlocker(_AbstractSignalBlocker):
         self,
         timeout: int = 1000,
         raising: bool = True,
-        check_params_cb: Optional[Callable] = None,
+        check_params_cb: Callable | None = None,
     ):
         super().__init__(timeout, raising=raising)
-        self._signals: List[QtCore.Signal] = []
-        self.args: Optional[Iterable] = None
-        self.all_args: List[tuple] = []
+        self._signals: list[QtCore.Signal] = []
+        self.args: Iterable | None = None
+        self.all_args: list[tuple] = []
         self.check_params_callback = check_params_cb
         self.signal_name = ""
 
-    def connect(self, signal: Union[QtCore.Signal, Tuple[QtCore.Signal, str]]):
+    def connect(self, signal: SignalOrSignalTuple):
         """Connect to given signal, making `wait()` return once this signal is emitted.
 
         More than one signal can be connected, in which case **any** one of
@@ -276,7 +276,7 @@ class SignalAndArgs:
         return self._get_readable_signal_with_optional_args()
 
     def __eq__(self, other):
-        if isinstance(other, self.__class__):
+        if isinstance(other, type(self)):
             return self.__dict__ == other.__dict__
         else:
             return False
@@ -284,7 +284,8 @@ class SignalAndArgs:
 
 # Returns e.g. "3rd" for 3, or "21st" for 21
 def get_ordinal_str(n) -> str:
-    return "%d%s" % (n, {1: "st", 2: "nd", 3: "rd"}.get(n if n < 20 else n % 10, "th"))
+    ordinal_dict = {1: "st", 2: "nd", 3: "rd"}
+    return "%d%s" % (n, ordinal_dict.get(n if n < 20 else n % 10, "th"))
 
 
 class NoMatchingIndexFoundError(Exception):
@@ -308,27 +309,27 @@ class MultiSignalBlocker(_AbstractSignalBlocker):
         self,
         timeout: int = 1000,
         raising: bool = True,
-        check_params_cbs=None,
-        order="none",
+        check_params_cbs: list[Callable] | None = None,
+        order: Literal["none", "simple", "strict"] = "none",
     ):
         super().__init__(timeout, raising=raising)
         self._order = order
         self._check_params_callbacks = check_params_cbs
-        self._signals_emitted: List[bool] = []
+        self._signals_emitted: list[bool] = []
         # list of booleans, indicates whether the signal was already emitted
-        self._signals_map: Dict[QtCore.Signal, List[int]] = {}
+        self._signals_map: dict[QtCore.Signal, list[int]] = {}
         # maps from a unique Signal to a list of indices where to expect signal emits
-        self._signals: List[QtCore.Signal] = []
+        self._signals: list[QtCore.Signal] = []
         # list of all Signals (for compatibility with _AbstractSignalBlocker)
-        self._slots: List[Callable] = []  # list of slot functions
+        self._slots: list[Callable] = []  # list of slot functions
         self._signal_expected_index = 0  # only used when forcing order
         self._strict_order_violated = False
-        self._actual_signal_and_args_at_violation: Optional[SignalAndArgs] = None
-        self._signal_names: Dict[QtCore.Signal, str] = {}
+        self._actual_signal_and_args_at_violation: SignalAndArgs | None = None
+        self._signal_names: dict[QtCore.Signal, str] = {}
         # maps from the unique Signal to the name of the signal (as string)
-        self.all_signals_and_args: List[SignalAndArgs] = []  # SignalAndArgs instances
+        self.all_signals_and_args: list[SignalAndArgs] = []  # SignalAndArgs instances
 
-    def add_signals(self, signals):
+    def add_signals(self, signals: Sequence[SignalOrSignalTuple]):
         """Add the given signal to the list of signals which :meth:`wait()` waits for.
 
         :param list signals: list of QtCore.Signal`s or tuples (QtCore.Signal, str)
@@ -345,14 +346,14 @@ class MultiSignalBlocker(_AbstractSignalBlocker):
             error_message = self._get_order_violation_message() + error_message
         return error_message
 
-    def _determine_unique_signals(self, signals):
+    def _determine_unique_signals(self, signals: Sequence[SignalOrSignalTuple]):
         # create a map that maps from a unique signal to a list of indices
         # (positions) where this signal is expected (in case order matters)
         signals_as_str = [
             str(self.get_signal_from_potential_signal_tuple(signal)) for signal in signals
         ]
         # maps from a signal-string to one of the signal instances (the first one found)
-        signal_str_to_unique_signal: Dict[str, QtCore.Signal] = {}
+        signal_str_to_unique_signal: dict[str, QtCore.Signal] = {}
         for index, signal_str in enumerate(signals_as_str):
             signal = self.get_signal_from_potential_signal_tuple(signals[index])
             potential_tuple = signals[index]
@@ -370,13 +371,12 @@ class MultiSignalBlocker(_AbstractSignalBlocker):
 
     def _determine_and_save_signal_name(self, unique_signal_tuple):
         signal_name = self.determine_signal_name(unique_signal_tuple)
-        if signal_name:  # might be an empty string if no name could be determined
-            unique_signal = self.get_signal_from_potential_signal_tuple(
-                unique_signal_tuple
-            )
-            self._signal_names[unique_signal] = signal_name
+        if not signal_name:  # might be an empty string if no name could be determined
+            return
+        unique_signal = self.get_signal_from_potential_signal_tuple(unique_signal_tuple)
+        self._signal_names[unique_signal] = signal_name
 
-    def _create_signal_emitted_indices(self, signals):
+    def _create_signal_emitted_indices(self, signals: Sequence[SignalOrSignalTuple]):
         for signal in signals:
             self._signals_emitted.append(False)
 
@@ -387,7 +387,7 @@ class MultiSignalBlocker(_AbstractSignalBlocker):
             unique_signal.connect(slot)
             self._signals.append(unique_signal)
 
-    def _unique_signal_emitted(self, unique_signal, *args):
+    def _unique_signal_emitted(self, unique_signal: QtCore.Signal, *args):
         """Called when a given signal is emitted.
 
         If all expected signals have been emitted, quits the event loop and
@@ -404,13 +404,13 @@ class MultiSignalBlocker(_AbstractSignalBlocker):
             finally:
                 self._loop.quit()
 
-    def _record_emitted_signal_if_possible(self, unique_signal, *args):
+    def _record_emitted_signal_if_possible(self, unique_signal: QtCore.Signal, *args):
         if self._are_signal_names_available():
             self.all_signals_and_args.append(
                 SignalAndArgs(signal_name=self._signal_names[unique_signal], args=args)
             )
 
-    def _check_signal_match(self, unique_signal, *args):
+    def _check_signal_match(self, unique_signal: QtCore.Signal, *args):
         if self._order == "none":
             # perform test for every matching index (stop after the first matching one)
             try:
@@ -439,10 +439,10 @@ class MultiSignalBlocker(_AbstractSignalBlocker):
                             signal_name=self._signal_names[unique_signal], args=args
                         )
 
-    def _all_signals_emitted(self):
+    def _all_signals_emitted(self) -> bool:
         return not self._strict_order_violated and all(self._signals_emitted)
 
-    def _get_first_matching_index(self, unique_signal, *args):
+    def _get_first_matching_index(self, unique_signal: QtCore.Signal, *args) -> int:
         successfully_emitted = False
         successful_index = -1
         potential_indices = self._get_unemitted_signal_indices(unique_signal)
@@ -456,7 +456,9 @@ class MultiSignalBlocker(_AbstractSignalBlocker):
 
         return successful_index
 
-    def _check_signal_matches_expected_index(self, unique_signal, *args):
+    def _check_signal_matches_expected_index(
+        self, unique_signal: QtCore.Signal, *args
+    ) -> bool:
         potential_indices = self._get_unemitted_signal_indices(unique_signal)
         if potential_indices:
             if self._signal_expected_index == potential_indices[0]:
@@ -466,7 +468,7 @@ class MultiSignalBlocker(_AbstractSignalBlocker):
                     return True
         return False
 
-    def _violates_callback_at_index(self, index, *args):
+    def _violates_callback_at_index(self, index, *args) -> bool:
         """Check callback at the provided index that is violated due to invalid params.
 
         Returns False if there is no callback for that index, or if a callback exists
@@ -479,13 +481,9 @@ class MultiSignalBlocker(_AbstractSignalBlocker):
                     return True
         return False
 
-    def _get_unemitted_signal_indices(self, signal):
+    def _get_unemitted_signal_indices(self, signal: QtCore.Signal) -> list[int]:
         """Return indices for provided signal for which NO signal has been emitted yet."""
-        return [
-            index
-            for index in self._signals_map[signal]
-            if not self._signals_emitted[index]
-        ]
+        return [i for i in self._signals_map[signal] if not self._signals_emitted[i]]
 
     def _are_signal_names_available(self) -> bool:
         return bool(self._signal_names)
@@ -516,24 +514,21 @@ class MultiSignalBlocker(_AbstractSignalBlocker):
         return f"Emitted signals: {emitted_signals}. Missing: {missing_signals}"
 
     @staticmethod
-    def _format_as_array(list_of_strings) -> str:
+    def _format_as_array(list_of_strings: Iterable[str]) -> str:
         return "[{}]".format(", ".join(list_of_strings))
 
     def _get_order_violation_message(self) -> str:
-        expected_signal_as_str = self._get_signal_string_representation_for_index(
+        expected_signal_str = self._get_signal_string_representation_for_index(
             self._signal_expected_index
         )
         actual_signal_as_str = str(self._actual_signal_and_args_at_violation)
+        ordinal = get_ordinal_str(self._signal_expected_index + 1)
         return (
-            "Signal order violated! Expected {expected} as {ordinal} signal, "
-            "but received {actual} instead. "
-        ).format(
-            expected=expected_signal_as_str,
-            ordinal=get_ordinal_str(self._signal_expected_index + 1),
-            actual=actual_signal_as_str,
+            f"Signal order violated! Expected {expected_signal_str} as {ordinal} signal, "
+            f"but received {actual_signal_as_str} instead. "
         )
 
-    def _get_missing_signal_indices(self) -> List[int]:
+    def _get_missing_signal_indices(self) -> list[int]:
         return [
             index
             for index, value in enumerate(self._signals_emitted)
@@ -592,14 +587,15 @@ class SignalEmittedSpy:
         self.signal.disconnect(self.slot)
 
     def assert_not_emitted(self):
-        if self.emitted:
-            if self.args:
-                raise SignalEmittedError(
-                    "Signal %r unexpectedly emitted with "
-                    "arguments %r" % (self.signal, list(self.args))
-                )
-            else:
-                raise SignalEmittedError(f"Signal {self.signal!r} unexpectedly emitted")
+        if not self.emitted:
+            return
+        if self.args:
+            raise SignalEmittedError(
+                f"Signal {self.signal!r} unexpectedly emitted with "
+                f"arguments {list(self.args)!r}"
+            )
+        else:
+            raise SignalEmittedError(f"Signal {self.signal!r} unexpectedly emitted")
 
 
 class CallbackBlocker:
@@ -628,11 +624,11 @@ class CallbackBlocker:
     def __init__(self, timeout: int = 1000, raising: bool = True):
         self.timeout = timeout
         self.raising = raising
-        self.args: Optional[list] = None
-        self.kwargs: Optional[dict] = None
+        self.args: list | None = None
+        self.kwargs: dict | None = None
         self.called = False
         self._loop = core.EventLoop()
-        self._timer: Optional[core.Timer] = None
+        self._timer: core.Timer | None = None
         if timeout is not None:
             self._timer = core.Timer(self._loop)
             self._timer.setSingleShot(True)
