@@ -1,22 +1,20 @@
 from __future__ import annotations
 
-from typing import Union
-
 from prettyqt import core
 from prettyqt.qt import QtCore, QtQml
 from prettyqt.utils import bidict
 
 
 COMPILATION_MODES = bidict(
-    prefer_synchronous=QtQml.QQmlComponent.PreferSynchronous,
-    asynchronous=QtQml.QQmlComponent.Asynchronous,
+    prefer_synchronous=QtQml.QQmlComponent.CompilationMode.PreferSynchronous,
+    asynchronous=QtQml.QQmlComponent.CompilationMode.Asynchronous,
 )
 
 STATUS = bidict(
-    null=QtQml.QQmlComponent.Null,
-    ready=QtQml.QQmlComponent.Ready,
-    loading=QtQml.QQmlComponent.Loading,
-    error=QtQml.QQmlComponent.Error,
+    null=QtQml.QQmlComponent.Status.Null,
+    ready=QtQml.QQmlComponent.Status.Ready,
+    loading=QtQml.QQmlComponent.Status.Loading,
+    error=QtQml.QQmlComponent.Status.Error,
 )
 
 QtQml.QQmlComponent.__bases__ = (core.Object,)
@@ -29,7 +27,7 @@ class QmlComponent(QtQml.QQmlComponent):
     def get_url(self) -> core.Url:
         return core.Url(self.url())
 
-    def load_url(self, url: Union[QtCore.QUrl, str], mode: str):
+    def load_url(self, url: QtCore.QUrl | str, mode: str):
         if isinstance(url, str):
             url = core.Url.from_user_input(url)
         self.loadUrl(url, COMPILATION_MODES[mode])
