@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import Optional, Union
-
 from prettyqt import widgets
 from prettyqt.qt import QtCore, QtHelp
 
@@ -10,7 +8,7 @@ QtHelp.QHelpContentWidget.__bases__ = (widgets.TreeView,)
 
 
 class HelpContentWidget(QtHelp.QHelpContentWidget):
-    def index_of(self, url: Union[QtCore.QUrl, str]) -> Optional[QtCore.QModelIndex]:
+    def index_of(self, url: QtCore.QUrl | str) -> QtCore.QModelIndex | None:
         if isinstance(url, str):
             url = QtCore.QUrl(url)
         idx = self.indexOf(url)
