@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import List, Optional, Union
-
 from prettyqt import core
 from prettyqt.qt import QtCore, QtHelp
 
@@ -17,15 +15,15 @@ class HelpEngineCore(QtHelp.QHelpEngineCore):
         self,
         namespace_name: str,
         filter_name: str,
-        extension_filter: Optional[str] = None,
-    ) -> List[core.Url]:
+        extension_filter: str | None = None,
+    ) -> list[core.Url]:
         if extension_filter is None:
             extension_filter = ""
         return [
             core.Url(i) for i in self.files(namespace_name, filter_name, extension_filter)
         ]
 
-    def find_file(self, url: Union[QtCore.QUrl, str]) -> core.Url:
+    def find_file(self, url: QtCore.QUrl | str) -> core.Url:
         if not isinstance(url, QtCore.QUrl):
             url = QtCore.QUrl(url)
         return core.Url(self.findFile(url))
