@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import os
 import pathlib
-from typing import Literal, Union
+from typing import Literal
 
 from prettyqt import core, gui
 from prettyqt.qt import QtCore, QtQuick
@@ -10,17 +10,17 @@ from prettyqt.utils import bidict
 
 
 RESIZE_MODES = bidict(
-    view_to_root_object=QtQuick.QQuickView.SizeViewToRootObject,
-    root_object_to_view=QtQuick.QQuickView.SizeRootObjectToView,
+    view_to_root_object=QtQuick.QQuickView.ResizeMode.SizeViewToRootObject,
+    root_object_to_view=QtQuick.QQuickView.ResizeMode.SizeRootObjectToView,
 )
 
 ResizeModeStr = Literal["view_to_root_object", "root_object_to_view"]
 
 STATUS = bidict(
-    null=QtQuick.QQuickView.Null,
-    ready=QtQuick.QQuickView.Ready,
-    loading=QtQuick.QQuickView.Loading,
-    error=QtQuick.QQuickView.Error,
+    null=QtQuick.QQuickView.Status.Null,
+    ready=QtQuick.QQuickView.Status.Ready,
+    loading=QtQuick.QQuickView.Status.Loading,
+    error=QtQuick.QQuickView.Status.Error,
 )
 
 StatusStr = Literal["null", "ready", "loading", "error"]
@@ -29,8 +29,8 @@ QtQuick.QQuickView.__bases__ = (gui.Window,)
 
 
 class QuickView(QtQuick.QQuickView):
-    def set_source(self, source: Union[str, os.PathLike, QtCore.QUrl]):
-        if isinstance(source, os.PathLike):  # type: ignore
+    def set_source(self, source: str | os.PathLike | QtCore.QUrl):
+        if isinstance(source, os.PathLike):
             source = os.fspath(source)
         if isinstance(source, str):
             source = core.Url.fromLocalFile(source)
