@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Any, List
+from typing import Any
 
 from bidict import bidict
 
@@ -8,7 +8,10 @@ from bidict import bidict
 class FlagMap:
     def __init__(self, initializer, **kwargs):
         self.initializer = initializer
-        kwargs = {k: int(v) for k, v in kwargs.items()}
+        try:
+            kwargs = {k: v.value for k, v in kwargs.items()}
+        except AttributeError:
+            kwargs = {k: int(v) for k, v in kwargs.items()}
         self.bidict: bidict[str, int] = bidict(**kwargs)
 
         class Inverter:
@@ -29,6 +32,6 @@ class FlagMap:
     def __getattr__(self, attr):
         return getattr(self.bidict, attr)
 
-    def get_list(self, flag) -> List[Any]:
+    def get_list(self, flag) -> list[Any]:
         flag = int(flag)
         return [k for k, v in self.bidict.items() if v & flag]
