@@ -1,10 +1,10 @@
 from __future__ import annotations
 
 import os
-from typing import Callable, Union
+from typing import Callable
 import webbrowser
 
-from prettyqt import core, webenginewidgets, widgets
+from prettyqt import core, webenginecore, widgets
 from prettyqt.qt import QtCore, QtWebEngineWidgets
 
 
@@ -14,9 +14,9 @@ QtWebEngineWidgets.QWebEngineView.__bases__ = (widgets.Widget,)
 class WebEngineView(QtWebEngineWidgets.QWebEngineView):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.setPage(webenginewidgets.WebEnginePage(self))
+        self.setPage(webenginecore.WebEnginePage(self))
 
-    def set_url(self, url: Union[QtCore.QUrl, str, os.PathLike]):
+    def set_url(self, url: QtCore.QUrl | str | os.PathLike):
         """Set the url of the WebEngineView.
 
         Clears the view and loads the URL.
@@ -24,7 +24,7 @@ class WebEngineView(QtWebEngineWidgets.QWebEngineView):
         Args:
             url: URL to set
         """
-        if isinstance(url, os.PathLike):  # type: ignore
+        if isinstance(url, os.PathLike):
             url = core.Url.fromLocalFile(os.fspath(url))
         elif isinstance(url, str):
             url = core.Url(url)
@@ -33,7 +33,7 @@ class WebEngineView(QtWebEngineWidgets.QWebEngineView):
     def get_url(self) -> core.Url:
         return core.Url(self.url())
 
-    def load_url(self, url: Union[QtCore.QUrl, str, os.PathLike]):
+    def load_url(self, url: QtCore.QUrl | str | os.PathLike):
         """Load the URL.
 
         Loads the specified url and displays it.
@@ -44,7 +44,7 @@ class WebEngineView(QtWebEngineWidgets.QWebEngineView):
         Args:
             url: URL to load
         """
-        if isinstance(url, os.PathLike):  # type: ignore
+        if isinstance(url, os.PathLike):
             url = core.Url.fromLocalFile(os.fspath(url))
         elif isinstance(url, str):
             url = core.Url(url)
@@ -95,26 +95,26 @@ class WebEngineView(QtWebEngineWidgets.QWebEngineView):
                 pass
 
             callback = do_nothing
-        flag = QtWebEngineWidgets.QWebEnginePage.FindFlags()
+        flag = webenginecore.WebEnginePage.FindFlag(0)
         if case_sensitive:
-            flag |= QtWebEngineWidgets.QWebEnginePage.FindCaseSensitively
+            flag |= webenginecore.WebEnginePage.FindFlag.FindCaseSensitively
         if backward:
-            flag |= QtWebEngineWidgets.QWebEnginePage.FindBackward
+            flag |= webenginecore.WebEnginePage.FindFlag.FindBackward
         self.findText(string, flag, callback)
 
-    def get_settings(self) -> webenginewidgets.WebEngineSettings:
+    def get_settings(self) -> webenginecore.WebEngineSettings:
         settings = self.settings()
-        return webenginewidgets.WebEngineSettings(settings)
+        return webenginecore.WebEngineSettings(settings)
 
     def set_setting(
         self,
-        setting_name: webenginewidgets.webenginesettings.WebAttributeStr,
+        setting_name: webenginecore.webenginesettings.WebAttributeStr,
         value: bool,
     ):
         self.get_settings()[setting_name] = value
 
     def get_setting(
-        self, setting_name: webenginewidgets.webenginesettings.WebAttributeStr
+        self, setting_name: webenginecore.webenginesettings.WebAttributeStr
     ) -> bool:
         return self.get_settings()[setting_name]
 
