@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import os
-from typing import Callable, Literal, Optional, Tuple, Union
+from typing import Callable, Literal
 
 from prettyqt import constants, core, gui, iconprovider
 from prettyqt.qt import QtCore, QtGui, QtWidgets
@@ -9,21 +9,21 @@ from prettyqt.utils import InvalidParamError, bidict, helpers, prettyprinter, ty
 
 
 PRIORITIES = bidict(
-    low=QtWidgets.QAction.LowPriority,
-    normal=QtWidgets.QAction.NormalPriority,
-    high=QtWidgets.QAction.HighPriority,
+    low=QtWidgets.QAction.Priority.LowPriority,
+    normal=QtWidgets.QAction.Priority.NormalPriority,
+    high=QtWidgets.QAction.Priority.HighPriority,
 )
 
 PriorityStr = Literal["low", "normal", "high"]
 
 ROLES = bidict(
-    none=QtWidgets.QAction.NoRole,
-    text_heuristic=QtWidgets.QAction.TextHeuristicRole,
-    application_specific=QtWidgets.QAction.ApplicationSpecificRole,
-    about_qt=QtWidgets.QAction.AboutQtRole,
-    about=QtWidgets.QAction.AboutRole,
-    preferences=QtWidgets.QAction.PreferencesRole,
-    quit=QtWidgets.QAction.QuitRole,
+    none=QtWidgets.QAction.MenuRole.NoRole,
+    text_heuristic=QtWidgets.QAction.MenuRole.TextHeuristicRole,
+    application_specific=QtWidgets.QAction.MenuRole.ApplicationSpecificRole,
+    about_qt=QtWidgets.QAction.MenuRole.AboutQtRole,
+    about=QtWidgets.QAction.MenuRole.AboutRole,
+    preferences=QtWidgets.QAction.MenuRole.PreferencesRole,
+    quit=QtWidgets.QAction.MenuRole.QuitRole,
 )
 
 RoleStr = Literal[
@@ -42,16 +42,16 @@ QtWidgets.QAction.__bases__ = (core.Object,)
 class Action(prettyprinter.PrettyPrinter, QtWidgets.QAction):
     def __init__(
         self,
-        parent: Optional[QtCore.QObject] = None,
+        parent: QtCore.QObject | None = None,
         text: str = "",
         icon: types.IconType = None,
-        shortcut: Optional[str] = None,
+        shortcut: str | None = None,
         tooltip: str = "",
         checkable: bool = False,
         checked: bool = False,
         statustip: str = "",
         enabled: bool = True,
-        callback: Optional[Callable] = None,
+        callback: Callable | None = None,
     ):
         super().__init__(parent)
         self._menu = None
@@ -132,10 +132,10 @@ class Action(prettyprinter.PrettyPrinter, QtWidgets.QAction):
 
     def set_tooltip(
         self,
-        tooltip: Union[str, os.PathLike],
-        size: Optional[Union[Tuple[int, int], QtCore.QSize]] = None,
+        tooltip: str | os.PathLike,
+        size: tuple[int, int] | QtCore.QSize | None = None,
     ):
-        if isinstance(tooltip, os.PathLike):  # type: ignore
+        if isinstance(tooltip, os.PathLike):
             path = os.fspath(tooltip)
             if size is None:
                 tooltip = f"<img src={path!r}>"
@@ -163,24 +163,28 @@ class Action(prettyprinter.PrettyPrinter, QtWidgets.QAction):
         icon = iconprovider.get_icon(icon)
         self.setIcon(icon)
 
-    def get_icon(self) -> Optional[gui.Icon]:
+    def get_icon(self) -> gui.Icon | None:
         icon = self.icon()
         if icon.isNull():
             return None
         return gui.Icon(icon)
 
-    def set_shortcut(self, shortcut: Union[None, QtGui.QKeySequence, str]):
+    def set_shortcut(self, shortcut: None | QtGui.QKeySequence | str):
         if shortcut is None:
             shortcut = ""
         if isinstance(shortcut, str):
-            shortcut = gui.KeySequence(shortcut, gui.KeySequence.PortableText)
+            shortcut = gui.KeySequence(
+                shortcut, gui.KeySequence.SequenceFormat.PortableText
+            )
         self.setShortcut(shortcut)
 
-    def get_shortcut(self) -> Optional[gui.KeySequence]:
+    def get_shortcut(self) -> gui.KeySequence | None:
         shortcut = self.shortcut()
         if not shortcut:
             return None
-        return gui.KeySequence(shortcut.toString(), gui.KeySequence.PortableText)
+        return gui.KeySequence(
+            shortcut.toString(), gui.KeySequence.SequenceFormat.PortableText
+        )
 
     def get_font(self) -> gui.Font:
         return gui.Font(self.font())
