@@ -4,7 +4,7 @@ import contextlib
 import logging
 import os
 import pathlib
-from typing import Dict, Iterator, Literal, Mapping, MutableMapping, Optional, Union
+from typing import Iterator, Mapping, MutableMapping
 
 import qstylizer.parser
 import qstylizer.style
@@ -24,7 +24,6 @@ SAVE_STATES = dict(
     headerviews=QtWidgets.QHeaderView,
 )
 
-ThemeStr = Literal["default", "dark"]
 
 QtWidgets.QApplication.__bases__ = (gui.GuiApplication,)
 
@@ -52,7 +51,7 @@ class Application(QtWidgets.QApplication):
         )
 
     def store_widget_states(
-        self, settings: Optional[MutableMapping] = None, key: str = "states"
+        self, settings: MutableMapping | None = None, key: str = "states"
     ):
         settings = core.Settings() if settings is None else settings
         result = {}
@@ -64,9 +63,7 @@ class Application(QtWidgets.QApplication):
             }
         settings[key] = result
 
-    def restore_widget_states(
-        self, settings: Optional[Mapping] = None, key: str = "states"
-    ):
+    def restore_widget_states(self, settings: Mapping | None = None, key: str = "states"):
         settings = core.Settings() if settings is None else settings
         for category, v in SAVE_STATES.items():
             items = settings[key].get(category)
@@ -91,7 +88,7 @@ class Application(QtWidgets.QApplication):
         popup.exec_()
 
     @classmethod
-    def get_mainwindow(cls) -> Optional[QtWidgets.QMainWindow]:
+    def get_mainwindow(cls) -> QtWidgets.QMainWindow | None:
         widget_list = cls.instance().topLevelWidgets()
         for widget in widget_list:
             if isinstance(widget, QtWidgets.QMainWindow):
@@ -99,7 +96,7 @@ class Application(QtWidgets.QApplication):
         return None
 
     @classmethod
-    def get_widget(cls, name: str) -> Optional[QtWidgets.QWidget]:
+    def get_widget(cls, name: str) -> QtWidgets.QWidget | None:
         mw = cls.get_mainwindow()
         if mw is None:
             logger.warning("Trying to get widget from nonexistent mainwindow")
@@ -117,10 +114,8 @@ class Application(QtWidgets.QApplication):
         yield ss
         self.set_stylesheet(ss)
 
-    def set_stylesheet(
-        self, ss: Union[None, str, qstylizer.style.StyleSheet, os.PathLike]
-    ):
-        if isinstance(ss, os.PathLike):  # type: ignore
+    def set_stylesheet(self, ss: None | str | qstylizer.style.StyleSheet | os.PathLike):
+        if isinstance(ss, os.PathLike):
             ss = pathlib.Path(ss).read_text()
         elif ss is None:
             ss = ""
@@ -129,7 +124,8 @@ class Application(QtWidgets.QApplication):
     def get_stylesheet(self) -> qstylizer.style.StyleSheet:
         return qstylizer.parser.parse(self.styleSheet())
 
-    def set_theme(self, theme: ThemeStr):
+    def set_theme(self, theme: constants.ThemeStr):
+        self.set_palette(theme)
         if theme == "default":
             self.set_stylesheet("")
             iconprovider.set_defaults(color="black")
@@ -139,10 +135,10 @@ class Application(QtWidgets.QApplication):
             iconprovider.set_defaults(color="lightblue")
 
     @classmethod
-    def get_available_themes(cls) -> Dict[ThemeStr, str]:
+    def get_available_themes(cls) -> dict[constants.ThemeStr, str]:
         return dict(default="Default", dark="Dark")
 
-    def send_event(self, obj_or_str: Union[str, QtCore.QObject], event: QtCore.QEvent):
+    def send_event(self, obj_or_str: str | QtCore.QObject, event: QtCore.QEvent):
         obj = self.get_widget(obj_or_str) if isinstance(obj_or_str, str) else obj_or_str
         if obj is None:
             raise ValueError(obj)
@@ -150,9 +146,9 @@ class Application(QtWidgets.QApplication):
 
     def post_event(
         self,
-        obj_or_str: Union[str, QtCore.QObject],
+        obj_or_str: str | QtCore.QObject,
         event: QtCore.QEvent,
-        priority: Union[int, constants.EventPriorityStr] = "normal",
+        priority: int | constants.EventPriorityStr = "normal",
     ):
         obj = self.get_widget(obj_or_str) if isinstance(obj_or_str, str) else obj_or_str
         if obj is None:
