@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import datetime
-from typing import Literal, Optional, Union
+from typing import Literal
 
 from prettyqt import widgets
 from prettyqt.qt import QtCore, QtWidgets
@@ -9,24 +9,24 @@ from prettyqt.utils import InvalidParamError, bidict
 
 
 SELECTION_MODE = bidict(
-    none=QtWidgets.QCalendarWidget.NoSelection,
-    single=QtWidgets.QCalendarWidget.SingleSelection,
+    none=QtWidgets.QCalendarWidget.SelectionMode.NoSelection,
+    single=QtWidgets.QCalendarWidget.SelectionMode.SingleSelection,
 )
 
 SelectionModeStr = Literal["none", "single"]
 
 VERTICAL_HEADER_FORMAT = bidict(
-    none=QtWidgets.QCalendarWidget.NoVerticalHeader,
-    week_numbers=QtWidgets.QCalendarWidget.ISOWeekNumbers,
+    none=QtWidgets.QCalendarWidget.VerticalHeaderFormat.NoVerticalHeader,
+    week_numbers=QtWidgets.QCalendarWidget.VerticalHeaderFormat.ISOWeekNumbers,
 )
 
 VerticalHeaderFormatStr = Literal["none", "week_numbers"]
 
 HORIZONTAL_HEADER_FORMAT = bidict(
-    single_letter=QtWidgets.QCalendarWidget.SingleLetterDayNames,
-    short=QtWidgets.QCalendarWidget.ShortDayNames,
-    long=QtWidgets.QCalendarWidget.LongDayNames,
-    none=QtWidgets.QCalendarWidget.NoHorizontalHeader,
+    single_letter=QtWidgets.QCalendarWidget.HorizontalHeaderFormat.SingleLetterDayNames,
+    short=QtWidgets.QCalendarWidget.HorizontalHeaderFormat.ShortDayNames,
+    long=QtWidgets.QCalendarWidget.HorizontalHeaderFormat.LongDayNames,
+    none=QtWidgets.QCalendarWidget.HorizontalHeaderFormat.NoHorizontalHeader,
 )
 
 HorizontalHeaderFormatStr = Literal["single_letter", "short", "long", "none"]
@@ -52,18 +52,18 @@ class CalendarWidget(QtWidgets.QCalendarWidget):
     def get_value(self) -> datetime.date:
         return self.get_date()
 
-    def set_value(self, value: Union[QtCore.QDate, datetime.date]):
+    def set_value(self, value: QtCore.QDate | datetime.date):
         self.setSelectedDate(value)  # type: ignore
 
     def set_range(
         self,
-        min_val: Union[QtCore.QDate, datetime.date],
-        max_val: Union[QtCore.QDate, datetime.date],
+        min_val: QtCore.QDate | datetime.date,
+        max_val: QtCore.QDate | datetime.date,
     ):
         self.setMinimumDate(min_val)  # type: ignore
         self.setMaximumDate(max_val)  # type: ignore
 
-    def set_selection_mode(self, mode: Optional[SelectionModeStr]):
+    def set_selection_mode(self, mode: SelectionModeStr | None):
         """Set selection mode for given calendar widget.
 
         Args:
