@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Literal, Optional
+from typing import Literal
 
 from prettyqt import constants, core
 from prettyqt.qt import QtWidgets
@@ -8,17 +8,17 @@ from prettyqt.utils import InvalidParamError, bidict
 
 
 COMPLETION_MODE = bidict(
-    popup=QtWidgets.QCompleter.PopupCompletion,
-    inline=QtWidgets.QCompleter.InlineCompletion,
-    unfiltered_popup=QtWidgets.QCompleter.UnfilteredPopupCompletion,
+    popup=QtWidgets.QCompleter.CompletionMode.PopupCompletion,
+    inline=QtWidgets.QCompleter.CompletionMode.InlineCompletion,
+    unfiltered_popup=QtWidgets.QCompleter.CompletionMode.UnfilteredPopupCompletion,
 )
 
 CompletionModeStr = Literal["popup", "inline", "unfiltered_popup"]
 
 SORT_MODE = bidict(
-    unsorted=QtWidgets.QCompleter.UnsortedModel,
-    case_sensitive=QtWidgets.QCompleter.CaseSensitivelySortedModel,
-    case_insensitive=QtWidgets.QCompleter.CaseInsensitivelySortedModel,
+    unsorted=QtWidgets.QCompleter.ModelSorting.UnsortedModel,
+    case_sensitive=QtWidgets.QCompleter.ModelSorting.CaseSensitivelySortedModel,
+    case_insensitive=QtWidgets.QCompleter.ModelSorting.CaseInsensitivelySortedModel,
 )
 
 SortModeStr = Literal["unsorted", "case_sensitive", "case_insensitive"]
@@ -28,10 +28,10 @@ QtWidgets.QCompleter.__bases__ = (core.Object,)
 
 
 class Completer(QtWidgets.QCompleter):
-    def __init__(self, parent: Optional[QtWidgets.QWidget] = None):
+    def __init__(self, parent: QtWidgets.QWidget | None = None):
         super().__init__(parent)
 
-    def set_sort_mode(self, mode: Optional[SortModeStr]):
+    def set_sort_mode(self, mode: SortModeStr | None):
         """Set sort mode to use.
 
         Args:
