@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import datetime
-from typing import List, Literal, Union
+from typing import Literal
 
 from prettyqt import core, widgets
 from prettyqt.qt import QtCore, QtWidgets
@@ -9,15 +9,15 @@ from prettyqt.utils import InvalidParamError, bidict
 
 
 SECTIONS = bidict(
-    none=QtWidgets.QDateTimeEdit.NoSection,
-    am_pm=QtWidgets.QDateTimeEdit.AmPmSection,
-    msec=QtWidgets.QDateTimeEdit.MSecSection,
-    second=QtWidgets.QDateTimeEdit.SecondSection,
-    minute=QtWidgets.QDateTimeEdit.MinuteSection,
-    hour=QtWidgets.QDateTimeEdit.HourSection,
-    day=QtWidgets.QDateTimeEdit.DaySection,
-    month=QtWidgets.QDateTimeEdit.MonthSection,
-    year=QtWidgets.QDateTimeEdit.YearSection,
+    none=QtWidgets.QDateTimeEdit.Section.NoSection,
+    am_pm=QtWidgets.QDateTimeEdit.Section.AmPmSection,
+    msec=QtWidgets.QDateTimeEdit.Section.MSecSection,
+    second=QtWidgets.QDateTimeEdit.Section.SecondSection,
+    minute=QtWidgets.QDateTimeEdit.Section.MinuteSection,
+    hour=QtWidgets.QDateTimeEdit.Section.HourSection,
+    day=QtWidgets.QDateTimeEdit.Section.DaySection,
+    month=QtWidgets.QDateTimeEdit.Section.MonthSection,
+    year=QtWidgets.QDateTimeEdit.Section.YearSection,
 )
 
 SectionsStr = Literal[
@@ -80,13 +80,13 @@ class DateTimeEdit(QtWidgets.QDateTimeEdit):
             raise InvalidParamError(section, SECTIONS)
         self.setCurrentSection(SECTIONS[section])
 
-    def get_displayed_sections(self) -> List[SectionsStr]:
+    def get_displayed_sections(self) -> list[SectionsStr]:
         return [k for k, v in SECTIONS.items() if v & self.displayedSections()]
 
     def set_range(
         self,
-        lower: Union[QtCore.QDateTime, datetime.datetime],
-        upper: Union[QtCore.QDateTime, datetime.datetime],
+        lower: QtCore.QDateTime | datetime.datetime,
+        upper: QtCore.QDateTime | datetime.datetime,
     ):
         self.setToolTip(f"{lower} <= x <= {upper}")
         self.setDateTimeRange(lower, upper)  # type: ignore
