@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import Optional, Union
-
 from prettyqt import widgets
 from prettyqt.qt import QtCore, QtWidgets
 
@@ -35,15 +33,15 @@ class BaseDialog(QtWidgets.QDialog):
         return type(self), (), self.__getstate__()
 
     def keyPressEvent(self, e):
-        if e.key() == QtCore.Qt.Key_Escape:
+        if e.key() == QtCore.Qt.Key.Key_Escape:
             self.close()
-        elif e.key() == QtCore.Qt.Key_F11:
+        elif e.key() == QtCore.Qt.Key.Key_F11:
             self.showNormal() if self.isMaximized() else self.showMaximized()
         else:
             super().keyPressEvent(e)
 
     def delete_on_close(self):
-        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setAttribute(QtCore.Qt.WidgetAttribute.WA_DeleteOnClose)
 
     def add_widget(self, widget: QtWidgets.QWidget) -> QtWidgets.QWidget:
         self.box += widget
@@ -56,11 +54,14 @@ class BaseDialog(QtWidgets.QDialog):
 
     def show_blocking(self) -> bool:
         self.show()
-        return bool(self.exec_())
+        return bool(self.main_loop())
 
     def is_accepted(self) -> bool:
         return self.result() == QtWidgets.QDialog.Accepted
 
+    def main_loop(self) -> int:
+        return self.exec_()
+
 
 class Dialog(BaseDialog):
 
@@ -70,9 +71,9 @@ class Dialog(BaseDialog):
         self,
         title: str = "",
         icon=None,
-        parent: Optional[QtWidgets.QWidget] = None,
+        parent: QtWidgets.QWidget | None = None,
         delete_on_close: bool = True,
-        layout: Union[None, str, QtWidgets.QLayout] = None,
+        layout: None | str | QtWidgets.QLayout = None,
     ):
         super().__init__(parent=parent)
         if self.DEFAULT_SIZE:
