@@ -1,20 +1,22 @@
 from __future__ import annotations
 
-from typing import Literal, Union
+from typing import Literal
 
 from prettyqt import gui
 from prettyqt.qt import QtCore, QtWidgets
 from prettyqt.utils import bidict
 
 
+mod = QtWidgets.QFileIconProvider
+
 ICON_TYPE = bidict(
-    computer=QtWidgets.QFileIconProvider.Computer,
-    desktop=QtWidgets.QFileIconProvider.Desktop,
-    trashcan=QtWidgets.QFileIconProvider.Trashcan,
-    network=QtWidgets.QFileIconProvider.Network,
-    drive=QtWidgets.QFileIconProvider.Drive,
-    folder=QtWidgets.QFileIconProvider.Folder,
-    file=QtWidgets.QFileIconProvider.File,
+    computer=mod.IconType.Computer,
+    desktop=mod.IconType.Desktop,
+    trashcan=mod.IconType.Trashcan,
+    network=mod.IconType.Network,
+    drive=mod.IconType.Drive,
+    folder=mod.IconType.Folder,
+    file=mod.IconType.File,
 )
 
 IconTypeStr = Literal[
@@ -22,14 +24,14 @@ IconTypeStr = Literal[
 ]
 
 OPTIONS = bidict(
-    dont_use_custom_dir_icons=QtWidgets.QFileIconProvider.DontUseCustomDirectoryIcons,
+    dont_use_custom_dir_icons=mod.Option.DontUseCustomDirectoryIcons,
 )
 
 OptionStr = Literal["dont_use_custom_dir_icons"]
 
 
 class FileIconProvider(QtWidgets.QFileIconProvider):
-    def get_icon(self, typ: Union[IconTypeStr, QtCore.QFileInfo]) -> gui.Icon:
+    def get_icon(self, typ: IconTypeStr | QtCore.QFileInfo) -> gui.Icon:
         if not isinstance(typ, QtCore.QFileInfo):
             param = ICON_TYPE[typ]
         else:
