@@ -1,32 +1,34 @@
 from __future__ import annotations
 
-from typing import Literal, Optional, Tuple, Union
+from typing import Literal
 
 from prettyqt import widgets
 from prettyqt.qt import QtWidgets
 from prettyqt.utils import InvalidParamError, bidict
 
 
+mod = QtWidgets.QFormLayout
+
 ROLE = bidict(
-    left=QtWidgets.QFormLayout.LabelRole,
-    right=QtWidgets.QFormLayout.FieldRole,
-    both=QtWidgets.QFormLayout.SpanningRole,
+    left=mod.ItemRole.LabelRole,
+    right=mod.ItemRole.FieldRole,
+    both=mod.ItemRole.SpanningRole,
 )
 
 RoleStr = Literal["left", "right", "both"]
 
 ROW_WRAP_POLICY = bidict(
-    dont_wrap=QtWidgets.QFormLayout.DontWrapRows,
-    wrap_long=QtWidgets.QFormLayout.WrapLongRows,
-    wrap_all=QtWidgets.QFormLayout.WrapAllRows,
+    dont_wrap=mod.RowWrapPolicy.DontWrapRows,
+    wrap_long=mod.RowWrapPolicy.WrapLongRows,
+    wrap_all=mod.RowWrapPolicy.WrapAllRows,
 )
 
 RowWrapPolicyStr = Literal["dont_wrap", "wrap_long", "wrap_all"]
 
 FIELD_GROWTH_POLICY = bidict(
-    fields_stay_at_size=QtWidgets.QFormLayout.FieldsStayAtSizeHint,
-    expanding_fields_grow=QtWidgets.QFormLayout.ExpandingFieldsGrow,
-    all_non_fixed_fields_grow=QtWidgets.QFormLayout.AllNonFixedFieldsGrow,
+    fields_stay_at_size=mod.FieldGrowthPolicy.FieldsStayAtSizeHint,
+    expanding_fields_grow=mod.FieldGrowthPolicy.ExpandingFieldsGrow,
+    all_non_fixed_fields_grow=mod.FieldGrowthPolicy.AllNonFixedFieldsGrow,
 )
 
 FieldGrowthPolicyStr = Literal[
@@ -43,7 +45,7 @@ class FormLayout(QtWidgets.QFormLayout):
         self.setVerticalSpacing(8)
 
     def __setitem__(
-        self, index: Union[int, Tuple[int, RoleStr]], value: Union[str, QtWidgets.QWidget]
+        self, index: int | tuple[int, RoleStr], value: str | QtWidgets.QWidget
     ):
         if isinstance(index, tuple):
             row = index[0]
@@ -63,7 +65,7 @@ class FormLayout(QtWidgets.QFormLayout):
         """Needed for PySide2."""
         return self.rowCount()
 
-    def __add__(self, other: Union[QtWidgets.QWidget, QtWidgets.QLayout, tuple]):
+    def __add__(self, other: QtWidgets.QWidget | QtWidgets.QLayout | tuple):
         self.add(other)
         return self
 
@@ -83,7 +85,7 @@ class FormLayout(QtWidgets.QFormLayout):
             self.set_widget(item, pos[0], pos[1])
 
     def set_widget(
-        self, widget: Union[str, QtWidgets.QWidget], row: int, role: RoleStr = "both"
+        self, widget: str | QtWidgets.QWidget, row: int, role: RoleStr = "both"
     ):
         if isinstance(widget, str):
             widget = widgets.Label(widget)
@@ -91,14 +93,14 @@ class FormLayout(QtWidgets.QFormLayout):
 
     def get_widget(
         self, row: int, role: RoleStr = "both"
-    ) -> Union[QtWidgets.QLayout, QtWidgets.QWidget]:
+    ) -> QtWidgets.QLayout | QtWidgets.QWidget:
         item = self.itemAt(row, ROLE[role])
         widget = item.widget()
         if widget is None:
             widget = item.layout()
         return widget
 
-    def get_item_position(self, index: int) -> Optional[Tuple[int, RoleStr]]:
+    def get_item_position(self, index: int) -> tuple[int, RoleStr] | None:
         pos = self.getItemPosition(index)  # type: ignore
         if pos[0] == -1:  # type: ignore
             return None
