@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import os
-from typing import List, Literal, Optional, Union
+from typing import Literal
 
 from prettyqt import constants, core, gui, widgets
 from prettyqt.qt import QtCore, QtWidgets
@@ -9,14 +9,14 @@ from prettyqt.utils import InvalidParamError, bidict, colors, helpers, types
 
 
 TEXT_INTERACTION = bidict(
-    none=QtCore.Qt.NoTextInteraction,
-    by_mouse=QtCore.Qt.TextSelectableByMouse,
-    by_keyboard=QtCore.Qt.TextSelectableByKeyboard,
-    accessible_by_mouse=QtCore.Qt.LinksAccessibleByMouse,
-    accessible_by_keyboard=QtCore.Qt.LinksAccessibleByKeyboard,
-    text_editable=QtCore.Qt.TextEditable,
-    like_text_editor=QtCore.Qt.TextEditorInteraction,
-    like_text_browser=QtCore.Qt.TextBrowserInteraction,
+    none=QtCore.Qt.TextInteractionFlag.NoTextInteraction,
+    by_mouse=QtCore.Qt.TextInteractionFlag.TextSelectableByMouse,
+    by_keyboard=QtCore.Qt.TextInteractionFlag.TextSelectableByKeyboard,
+    accessible_by_mouse=QtCore.Qt.TextInteractionFlag.LinksAccessibleByMouse,
+    accessible_by_keyboard=QtCore.Qt.TextInteractionFlag.LinksAccessibleByKeyboard,
+    text_editable=QtCore.Qt.TextInteractionFlag.TextEditable,
+    like_text_editor=QtCore.Qt.TextInteractionFlag.TextEditorInteraction,
+    like_text_browser=QtCore.Qt.TextInteractionFlag.TextBrowserInteraction,
 )
 
 TextInteractionStr = Literal[
@@ -31,11 +31,13 @@ TextInteractionStr = Literal[
 ]
 
 TEXT_FORMAT = bidict(
-    rich=QtCore.Qt.RichText, plain=QtCore.Qt.PlainText, auto=QtCore.Qt.AutoText
+    rich=QtCore.Qt.TextFormat.RichText,
+    plain=QtCore.Qt.TextFormat.PlainText,
+    auto=QtCore.Qt.TextFormat.AutoText,
 )
 
 if core.VersionNumber.get_qt_version() >= (5, 14, 0):
-    TEXT_FORMAT["markdown"] = QtCore.Qt.MarkdownText
+    TEXT_FORMAT["markdown"] = QtCore.Qt.TextFormat.MarkdownText
 
 TextFormatStr = Literal["rich", "plain", "auto", "markdown"]
 
@@ -85,15 +87,17 @@ class Label(QtWidgets.QLabel):
 
     def allow_links(self) -> Label:
         # self.setText("<a href=\"http://example.com/\">Click Here!</a>")
-        self.setTextFormat(QtCore.Qt.RichText)
-        self.setTextInteractionFlags(QtCore.Qt.TextBrowserInteraction)
+        self.setTextFormat(QtCore.Qt.TextFormat.RichText)
+        self.setTextInteractionFlags(
+            QtCore.Qt.TextInteractionFlag.TextBrowserInteraction  # type: ignore
+        )
         self.setOpenExternalLinks(True)
         return self
 
     def set_alignment(
         self,
-        horizontal: Optional[constants.HorizontalAlignmentStr] = None,
-        vertical: Optional[constants.VerticalAlignmentStr] = None,
+        horizontal: constants.HorizontalAlignmentStr | None = None,
+        vertical: constants.VerticalAlignmentStr | None = None,
     ):
         """Set the alignment of the label's contents."""
         if horizontal is None and vertical is not None:
@@ -109,22 +113,22 @@ class Label(QtWidgets.QLabel):
 
     def get_horizontal_alignment(self) -> constants.HorizontalAlignmentStr:
         align = self.alignment()
-        if align & QtCore.Qt.AlignRight:
+        if align & constants.ALIGN_RIGHT:  # type: ignore
             return "right"
-        elif align & QtCore.Qt.AlignHCenter:
+        elif align & constants.ALIGN_H_CENTER:  # type: ignore
             return "center"
-        elif align & QtCore.Qt.AlignJustify:
+        elif align & constants.ALIGN_JUSTIFY:  # type: ignore
             return "justify"
         else:
             return "left"
 
     def get_vertical_alignment(self) -> constants.VerticalAlignmentStr:
         align = self.alignment()
-        if align & QtCore.Qt.AlignTop:
+        if align & constants.ALIGN_TOP:  # type: ignore
             return "top"
-        elif align & QtCore.Qt.AlignBottom:
+        elif align & constants.ALIGN_BOTTOM:  # type: ignore
             return "bottom"
-        elif align & QtCore.Qt.AlignBaseline:
+        elif align & constants.ALIGN_BASELINE:  # type: ignore
             return "baseline"
         else:
             return "center"
@@ -172,7 +176,7 @@ class Label(QtWidgets.QLabel):
         self.setTextInteractionFlags(flags)
         return self
 
-    def get_text_interaction(self) -> List[TextInteractionStr]:
+    def get_text_interaction(self) -> list[TextInteractionStr]:
         """Return current text interaction mode.
 
         Returns:
@@ -228,7 +232,7 @@ class Label(QtWidgets.QLabel):
                 ss.color.setValue(color.name())
         return self
 
-    def set_image(self, path: Union[os.PathLike, str], width: int = 300) -> Label:
+    def set_image(self, path: os.PathLike | str, width: int = 300) -> Label:
         self.setScaledContents(True)
         self.set_alignment(horizontal="center")
         self.setText(
@@ -240,7 +244,7 @@ class Label(QtWidgets.QLabel):
 
     @classmethod
     def image_from_path(
-        cls, path: Union[os.PathLike, str], parent: Optional[QtWidgets.QWidget] = None
+        cls, path: os.PathLike | str, parent: QtWidgets.QWidget | None = None
     ) -> Label:
         pixmap = gui.Pixmap.from_file(path)
         label = cls(parent=parent)
