@@ -1,24 +1,24 @@
 from __future__ import annotations
 
-from typing import Literal, Optional
+from typing import Literal
 
 from prettyqt import constants, core, gui, widgets
-from prettyqt.qt import QtWidgets
+from prettyqt.qt import QtCore, QtWidgets
 from prettyqt.utils import InvalidParamError, bidict
 
 
 ECHO_MODE = bidict(
-    normal=QtWidgets.QLineEdit.Normal,
-    no_echo=QtWidgets.QLineEdit.NoEcho,
-    password=QtWidgets.QLineEdit.Password,
-    echo_on_edit=QtWidgets.QLineEdit.PasswordEchoOnEdit,
+    normal=QtWidgets.QLineEdit.EchoMode.Normal,
+    no_echo=QtWidgets.QLineEdit.EchoMode.NoEcho,
+    password=QtWidgets.QLineEdit.EchoMode.Password,
+    echo_on_edit=QtWidgets.QLineEdit.EchoMode.PasswordEchoOnEdit,
 )
 
 EchoModeStr = Literal["normal", "no_echo", "password", "echo_on_edit"]
 
 ACTION_POSITION = bidict(
-    leading=QtWidgets.QLineEdit.LeadingPosition,
-    trailing=QtWidgets.QLineEdit.TrailingPosition,
+    leading=QtWidgets.QLineEdit.ActionPosition.LeadingPosition,
+    trailing=QtWidgets.QLineEdit.ActionPosition.TrailingPosition,
 )
 
 ActionPositionStr = Literal["leading", "trailing"]
@@ -27,6 +27,9 @@ QtWidgets.QLineEdit.__bases__ = (widgets.Widget,)
 
 
 class LineEdit(QtWidgets.QLineEdit):
+    focusLost = core.Signal()
+    enterPressed = core.Signal()
+    editComplete = core.Signal(str)
 
     value_changed = core.Signal(str)
 
@@ -34,7 +37,7 @@ class LineEdit(QtWidgets.QLineEdit):
         self,
         default_value: str = "",
         read_only: bool = False,
-        parent: Optional[QtWidgets.QWidget] = None,
+        parent: QtWidgets.QWidget | None = None,
     ):
         super().__init__(default_value, parent)
         self.textChanged.connect(self._set_validation_color)
@@ -86,6 +89,18 @@ class LineEdit(QtWidgets.QLineEdit):
             is_modified=self.isModified(),
         )
 
+    def focusOutEvent(self, event):
+        self.focusLost.emit()
+        return super().focusOutEvent(event)
+
+    def keyPressEvent(self, event):
+        if event.key() in [QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return]:
+            self.enterPressed.emit()
+        return super().keyPressEvent(event)
+
+    def _on_edit_complete(self):
+        self.editComplete.emit(self.text())
+
     def font(self) -> gui.Font:
         return gui.Font(super().font())
 
@@ -109,7 +124,7 @@ class LineEdit(QtWidgets.QLineEdit):
         self.set_validator(validator)
         return validator
 
-    def set_range(self, lower: Optional[int], upper: Optional[int]):
+    def set_range(self, lower: int | None, upper: int | None):
         val = gui.IntValidator()
         val.set_range(lower, upper)
         self.set_validator(val)
