@@ -2,43 +2,43 @@ from __future__ import annotations
 
 import sys
 import traceback
-from typing import List, Literal, Optional, Union
+from typing import Literal
 
-from prettyqt import core, iconprovider, widgets
+from prettyqt import core, gui, iconprovider, widgets
 from prettyqt.qt import QtCore, QtWidgets
 from prettyqt.utils import InvalidParamError, bidict, types
 
 
 ICONS = bidict(
-    none=QtWidgets.QMessageBox.NoIcon,
-    information=QtWidgets.QMessageBox.Information,
-    warning=QtWidgets.QMessageBox.Warning,
-    critical=QtWidgets.QMessageBox.Critical,
-    question=QtWidgets.QMessageBox.Question,
+    none=QtWidgets.QMessageBox.Icon.NoIcon,
+    information=QtWidgets.QMessageBox.Icon.Information,
+    warning=QtWidgets.QMessageBox.Icon.Warning,
+    critical=QtWidgets.QMessageBox.Icon.Critical,
+    question=QtWidgets.QMessageBox.Icon.Question,
 )
 
 IconStr = Literal["none", "information", "warning", "critical", "question"]
 
 BUTTONS = bidict(
-    none=QtWidgets.QMessageBox.NoButton,
-    cancel=QtWidgets.QMessageBox.Cancel,
-    ok=QtWidgets.QMessageBox.Ok,
-    save=QtWidgets.QMessageBox.Save,
-    open=QtWidgets.QMessageBox.Open,
-    close=QtWidgets.QMessageBox.Close,
-    discard=QtWidgets.QMessageBox.Discard,
-    apply=QtWidgets.QMessageBox.Apply,
-    reset=QtWidgets.QMessageBox.Reset,
-    restore_defaults=QtWidgets.QMessageBox.RestoreDefaults,
-    help=QtWidgets.QMessageBox.Help,
-    save_all=QtWidgets.QMessageBox.SaveAll,
-    yes=QtWidgets.QMessageBox.Yes,
-    yes_to_all=QtWidgets.QMessageBox.YesToAll,
-    no=QtWidgets.QMessageBox.No,
-    no_to_all=QtWidgets.QMessageBox.NoToAll,
-    abort=QtWidgets.QMessageBox.Abort,
-    retry=QtWidgets.QMessageBox.Retry,
-    ignore=QtWidgets.QMessageBox.Ignore,
+    none=QtWidgets.QMessageBox.StandardButton.NoButton,
+    cancel=QtWidgets.QMessageBox.StandardButton.Cancel,
+    ok=QtWidgets.QMessageBox.StandardButton.Ok,
+    save=QtWidgets.QMessageBox.StandardButton.Save,
+    open=QtWidgets.QMessageBox.StandardButton.Open,
+    close=QtWidgets.QMessageBox.StandardButton.Close,
+    discard=QtWidgets.QMessageBox.StandardButton.Discard,
+    apply=QtWidgets.QMessageBox.StandardButton.Apply,
+    reset=QtWidgets.QMessageBox.StandardButton.Reset,
+    restore_defaults=QtWidgets.QMessageBox.StandardButton.RestoreDefaults,
+    help=QtWidgets.QMessageBox.StandardButton.Help,
+    save_all=QtWidgets.QMessageBox.StandardButton.SaveAll,
+    yes=QtWidgets.QMessageBox.StandardButton.Yes,
+    yes_to_all=QtWidgets.QMessageBox.StandardButton.YesToAll,
+    no=QtWidgets.QMessageBox.StandardButton.No,
+    no_to_all=QtWidgets.QMessageBox.StandardButton.NoToAll,
+    abort=QtWidgets.QMessageBox.StandardButton.Abort,
+    retry=QtWidgets.QMessageBox.StandardButton.Retry,
+    ignore=QtWidgets.QMessageBox.StandardButton.Ignore,
 )
 
 ButtonStr = Literal[
@@ -63,11 +63,39 @@ ButtonStr = Literal[
     "ignore",
 ]
 
+BUTTON_ROLE = bidict(
+    invalid=QtWidgets.QMessageBox.ButtonRole.InvalidRole,
+    accept=QtWidgets.QMessageBox.ButtonRole.AcceptRole,
+    reject=QtWidgets.QMessageBox.ButtonRole.RejectRole,
+    destructive=QtWidgets.QMessageBox.ButtonRole.DestructiveRole,
+    action=QtWidgets.QMessageBox.ButtonRole.ActionRole,
+    help=QtWidgets.QMessageBox.ButtonRole.HelpRole,
+    yes=QtWidgets.QMessageBox.ButtonRole.YesRole,
+    no=QtWidgets.QMessageBox.ButtonRole.NoRole,
+    apply=QtWidgets.QMessageBox.ButtonRole.ApplyRole,
+    reset=QtWidgets.QMessageBox.ButtonRole.ResetRole,
+)
+
+ButtonRoleStr = Literal[
+    "invalid",
+    "accept",
+    "reject",
+    "destructive",
+    "action",
+    "help",
+    "yes",
+    "no",
+    "apply",
+    "reset",
+]
+
 TEXT_FORMAT = bidict(
-    rich=QtCore.Qt.RichText, plain=QtCore.Qt.PlainText, auto=QtCore.Qt.AutoText
+    rich=QtCore.Qt.TextFormat.RichText,
+    plain=QtCore.Qt.TextFormat.PlainText,
+    auto=QtCore.Qt.TextFormat.AutoText,
 )
 if core.VersionNumber.get_qt_version() >= (5, 14, 0):
-    TEXT_FORMAT["markdown"] = QtCore.Qt.MarkdownText
+    TEXT_FORMAT["markdown"] = QtCore.Qt.TextFormat.MarkdownText
 
 TextFormatStr = Literal["rich", "plain", "auto"]
 
@@ -82,8 +110,8 @@ class MessageBox(QtWidgets.QMessageBox):
         text: str = "",
         informative_text: str = "",
         details: str = "",
-        buttons: Optional[list] = None,
-        parent: Optional[QtWidgets.QWidget] = None,
+        buttons: list[ButtonStr] | None = None,
+        parent: QtWidgets.QWidget | None = None,
     ):
         super().__init__(parent)
         self.set_icon(icon)
@@ -91,20 +119,32 @@ class MessageBox(QtWidgets.QMessageBox):
         self.setInformativeText(informative_text)
         self.setWindowTitle(title)
         self.setWindowFlags(
-            QtCore.Qt.Dialog | QtCore.Qt.WindowTitleHint | QtCore.Qt.CustomizeWindowHint
+            QtCore.Qt.WindowType.Dialog  # type: ignore
+            | QtCore.Qt.WindowType.WindowTitleHint
+            | QtCore.Qt.WindowType.CustomizeWindowHint
         )
         self.setDetailedText(details)
         if isinstance(buttons, list):
             for b in buttons:
                 self.add_button(b)
 
+    def serialize_fields(self):
+        return dict(
+            icon=self.get_icon(),
+            detailed_text=self.detailedText(),
+            icon_pixmap=self.get_icon_pixmap(),
+            informative_text=self.informativeText(),
+            text=self.text(),
+            text_format=self.get_text_format(),
+        )
+
     @classmethod
     def message(
         cls,
         text: str,
         title: str = "",
         icon: types.IconType = None,
-        detail_text: Optional[str] = None,
+        detail_text: str | None = None,
     ) -> str:
         m = cls("none", title, text)
         m.set_icon(icon)
@@ -119,7 +159,7 @@ class MessageBox(QtWidgets.QMessageBox):
         dlg = cls(text=str(value), title=str(exctype), icon="critical", details=tb)
         dlg.show_blocking()
 
-    def set_icon(self, icon: Union[types.IconType, IconStr]):
+    def set_icon(self, icon: types.IconType | IconStr):
         if icon in ICONS:
             self.setIcon(ICONS[icon])
         else:
@@ -127,9 +167,15 @@ class MessageBox(QtWidgets.QMessageBox):
             self.setIconPixmap(ico.get_pixmap(size=64))
 
     def show_blocking(self) -> ButtonStr:
-        return BUTTONS.inverse[self.exec_()]
+        return BUTTONS.inverse[self.main_loop()]
 
-    def get_standard_buttons(self) -> List[ButtonStr]:
+    def get_icon_pixmap(self) -> gui.Pixmap | None:
+        pix = self.iconPixmap()
+        if pix.isNull():
+            return None
+        return gui.Pixmap(pix)
+
+    def get_standard_buttons(self) -> list[ButtonStr]:
         return [k for k, v in BUTTONS.items() if v & self.standardButtons()]
 
     def add_button(self, button: ButtonStr) -> QtWidgets.QPushButton:
@@ -175,6 +221,18 @@ class MessageBox(QtWidgets.QMessageBox):
         """
         return TEXT_FORMAT.inverse[self.textFormat()]
 
+    def set_escape_button(self, button: ButtonStr | QtWidgets.QAbstractButton):
+        if isinstance(button, QtWidgets.QAbstractButton):
+            self.setEscapeButton(button)
+        else:
+            self.setEscapeButton(BUTTONS[button])
+
+    def set_default_button(self, button: ButtonStr | QtWidgets.QPushButton):
+        if isinstance(button, QtWidgets.QPushButton):
+            self.setDefaultButton(button)
+        else:
+            self.setDefaultButton(BUTTONS[button])
+
 
 if __name__ == "__main__":
     app = widgets.app()
