@@ -1,18 +1,19 @@
 from __future__ import annotations
 
 import contextlib
-from typing import Iterator, Literal, Optional
+from typing import Iterator, Literal
 
 from deprecated import deprecated
 
+import prettyqt
 from prettyqt import constants, core, gui, syntaxhighlighters, widgets
 from prettyqt.qt import QtGui, QtWidgets
-from prettyqt.utils import InvalidParamError, bidict
+from prettyqt.utils import InvalidParamError, bidict, colors, types
 
 
 LINE_WRAP_MODE = bidict(
-    none=QtWidgets.QPlainTextEdit.NoWrap,
-    widget_width=QtWidgets.QPlainTextEdit.WidgetWidth,
+    none=QtWidgets.QPlainTextEdit.LineWrapMode.NoWrap,
+    widget_width=QtWidgets.QPlainTextEdit.LineWrapMode.WidgetWidth,
 )
 
 LineWrapModeStr = Literal["none", "widget_width"]
@@ -28,12 +29,12 @@ class PlainTextEdit(QtWidgets.QPlainTextEdit):
     def __init__(
         self,
         text: str = "",
-        parent: Optional[QtWidgets.QWidget] = None,
+        parent: QtWidgets.QWidget | None = None,
         read_only: bool = False,
     ):
         super().__init__(text, parent)
         self._allow_wheel_zoom = False
-        self.validator: Optional[QtGui.QValidator] = None
+        self.validator: QtGui.QValidator | None = None
         self.textChanged.connect(self._on_value_change)
         self.set_read_only(read_only)
 
@@ -71,6 +72,31 @@ class PlainTextEdit(QtWidgets.QPlainTextEdit):
     def allow_wheel_zoom(self, do_zoom: bool = True):
         self._allow_wheel_zoom = do_zoom
 
+    def goto_line(self, line_no: int):
+        doc = self.document()
+        lines = doc.blockCount()
+        assert 1 <= line_no <= lines
+        pos = doc.findBlockByLineNumber(line_no - 1).position()
+        with self.current_cursor() as text_cursor:
+            text_cursor.setPosition(pos)
+
+    def get_selected_text(self) -> str:
+        if self.textCursor().hasSelection():
+            return self.textCursor().selectedText()
+        else:
+            return ""
+
+    def get_current_line(self) -> int:
+        return self.textCursor().blockNumber()
+
+    def get_selected_rows(self) -> tuple[int, int]:
+        start = self.textCursor().selectionStart()
+        end = self.textCursor().selectionEnd()
+        start_block_id = self.document().findBlock(start).blockNumber()
+        end_block_id = self.document().findBlock(end).blockNumber()
+
+        return (start_block_id, end_block_id)
+
     @contextlib.contextmanager
     def create_cursor(self) -> Iterator[gui.TextCursor]:
         cursor = gui.TextCursor(self.document())
@@ -103,7 +129,7 @@ class PlainTextEdit(QtWidgets.QPlainTextEdit):
     def set_text(self, text: str):
         self.setPlainText(text)
 
-    def set_syntaxhighlighter(self, syntax: str, style: Optional[str] = None):
+    def set_syntaxhighlighter(self, syntax: str, style: str | None = None):
         self._hl = syntaxhighlighters.PygmentsHighlighter(self.document(), syntax)
         if style is not None:
             self._hl.set_style(style)
@@ -123,14 +149,21 @@ class PlainTextEdit(QtWidgets.QPlainTextEdit):
         """
         self.setReadOnly(value)
 
-    def highlight_current_line(self, color="yellow"):
+    def highlight_current_line(self, color: types.ColorType = None):
+        if color is None:
+            color = self.get_palette().get_color("highlight")
+        else:
+            color = colors.get_color(color)
         extra_selections = []
 
         if not self.isReadOnly():
             selection = widgets.TextEdit.ExtraSelection()
-            line_color = gui.Color(color)
-            selection.format.setBackground(line_color)
-            selection.format.setProperty(QtGui.QTextFormat.FullWidthSelection, True)
+            selection.format.setBackground(color)
+            if prettyqt.qt.API != "pyqt6":
+                prop = QtGui.QTextFormat.FullWidthSelection
+            else:
+                prop = QtGui.QTextFormat.Property.FullWidthSelection  # type: ignore
+                selection.format.setProperty(prop, True)
             selection.cursor = self.textCursor()
             selection.cursor.clearSelection()
             extra_selections.append(selection)
@@ -196,7 +229,7 @@ class PlainTextEdit(QtWidgets.QPlainTextEdit):
         color = "orange" if not self.is_valid() else None
         self.set_background_color(color)
 
-    def set_validator(self, validator: Optional[QtGui.QValidator]):
+    def set_validator(self, validator: QtGui.QValidator | None):
         self.validator = validator
         self._set_validation_color()
 
