@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Literal, Optional
+from typing import Literal
 
 from prettyqt import constants, widgets
 from prettyqt.qt import QtWidgets
@@ -8,8 +8,8 @@ from prettyqt.utils import InvalidParamError, bidict
 
 
 TEXT_DIRECTIONS = bidict(
-    top_to_bottom=QtWidgets.QProgressBar.TopToBottom,
-    bottom_to_top=QtWidgets.QProgressBar.BottomToTop,
+    top_to_bottom=QtWidgets.QProgressBar.Direction.TopToBottom,
+    bottom_to_top=QtWidgets.QProgressBar.Direction.BottomToTop,
 )
 
 TextDirectionStr = Literal["top_to_bottom", "bottom_to_top"]
@@ -25,7 +25,7 @@ class ProgressBar(QtWidgets.QProgressBar):
     """
 
     def __init__(
-        self, text_visible: bool = True, parent: Optional[QtWidgets.QWidget] = None
+        self, text_visible: bool = True, parent: QtWidgets.QWidget | None = None
     ):
         super().__init__(parent=parent)
         self.setTextVisible(text_visible)
