@@ -1,10 +1,9 @@
 from __future__ import annotations
 
 import os
-from typing import Optional, Union
 
 from prettyqt import constants, gui, widgets
-from prettyqt.qt import QtCore, QtGui, QtWidgets
+from prettyqt.qt import QtGui, QtWidgets
 from prettyqt.utils import types
 
 
@@ -12,16 +11,12 @@ QtWidgets.QSplashScreen.__bases__ = (widgets.Widget,)
 
 
 class SplashScreen(QtWidgets.QSplashScreen):
-    def __init__(
-        self, path: Union[os.PathLike, str, QtGui.QPixmap], width: Optional[int] = None
-    ):
+    def __init__(self, path: os.PathLike | str | QtGui.QPixmap, width: int | None = None):
         pix = gui.Pixmap(os.fspath(path)) if not isinstance(path, QtGui.QPixmap) else path
         if width:
             pix = pix.scaledToWidth(width)
         super().__init__(pix)
-        self.setWindowFlags(
-            QtCore.Qt.WindowStaysOnTopHint | QtCore.Qt.FramelessWindowHint
-        )
+        self.set_flags(stay_on_top=True, frameless=True)
         self.setEnabled(False)
 
     def __enter__(self):
