@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Literal, Optional, Tuple, Union
+from typing import Literal
 
 from deprecated import deprecated
 
@@ -10,22 +10,22 @@ from prettyqt.utils import InvalidParamError, bidict
 
 
 REMOVE_BEHAVIOUR = bidict(
-    left_tab=QtWidgets.QTabBar.SelectLeftTab,
-    right_tab=QtWidgets.QTabBar.SelectRightTab,
-    previous_tab=QtWidgets.QTabBar.SelectPreviousTab,
+    left_tab=QtWidgets.QTabBar.SelectionBehavior.SelectLeftTab,
+    right_tab=QtWidgets.QTabBar.SelectionBehavior.SelectRightTab,
+    previous_tab=QtWidgets.QTabBar.SelectionBehavior.SelectPreviousTab,
 )
 
 RemoveBehaviourStr = Literal["left_tab", "right_tab", "previous_tab"]
 
 SHAPE = bidict(
-    rounded_north=QtWidgets.QTabBar.RoundedNorth,
-    rounded_south=QtWidgets.QTabBar.RoundedSouth,
-    rounded_west=QtWidgets.QTabBar.RoundedWest,
-    rounded_east=QtWidgets.QTabBar.RoundedEast,
-    triangular_north=QtWidgets.QTabBar.TriangularNorth,
-    triangular_south=QtWidgets.QTabBar.TriangularSouth,
-    triangular_west=QtWidgets.QTabBar.TriangularWest,
-    triangular_east=QtWidgets.QTabBar.TriangularEast,
+    rounded_north=QtWidgets.QTabBar.Shape.RoundedNorth,
+    rounded_south=QtWidgets.QTabBar.Shape.RoundedSouth,
+    rounded_west=QtWidgets.QTabBar.Shape.RoundedWest,
+    rounded_east=QtWidgets.QTabBar.Shape.RoundedEast,
+    triangular_north=QtWidgets.QTabBar.Shape.TriangularNorth,
+    triangular_south=QtWidgets.QTabBar.Shape.TriangularSouth,
+    triangular_west=QtWidgets.QTabBar.Shape.TriangularWest,
+    triangular_east=QtWidgets.QTabBar.Shape.TriangularEast,
 )
 
 ShapeStr = Literal[
@@ -39,7 +39,10 @@ ShapeStr = Literal[
     "triangular_east",
 ]
 
-POSITIONS = bidict(left=QtWidgets.QTabBar.LeftSide, right=QtWidgets.QTabBar.RightSide)
+POSITIONS = bidict(
+    left=QtWidgets.QTabBar.ButtonPosition.LeftSide,
+    right=QtWidgets.QTabBar.ButtonPosition.RightSide,
+)
 
 PositionStr = Literal["left", "right"]
 
@@ -49,18 +52,18 @@ QtWidgets.QTabBar.__bases__ = (widgets.Widget,)
 class TabBar(QtWidgets.QTabBar):
     on_detach = QtCore.Signal(int, QtCore.QPoint)
 
-    def __init__(self, parent: Optional[QtWidgets.QWidget] = None) -> None:
+    def __init__(self, parent: QtWidgets.QWidget | None = None) -> None:
         super().__init__(parent)
 
         self.setAcceptDrops(True)
         self.set_elide_mode("right")
         self.set_selection_behavior_on_remove("left_tab")
 
-    def __getitem__(self, index: Tuple[int, str]):
+    def __getitem__(self, index: tuple[int, str]):
         return self.tabButton(index[0], POSITIONS[index[1]])
 
     def __setitem__(
-        self, index: Tuple[int, PositionStr], value: Optional[QtWidgets.QWidget]
+        self, index: tuple[int, PositionStr], value: QtWidgets.QWidget | None
     ):
         self.set_tab(index[0], index[1], value)
 
@@ -94,7 +97,7 @@ class TabBar(QtWidgets.QTabBar):
         pos = QtGui.QCursor.pos()
         self.on_detach.emit(tab, pos)
 
-    def set_icon_size(self, size: Union[int, Tuple[int, int], QtCore.QSize]):
+    def set_icon_size(self, size: int | tuple[int, int] | QtCore.QSize):
         """Set size of the icons."""
         if isinstance(size, int):
             size = core.Size(size, size)
@@ -106,7 +109,7 @@ class TabBar(QtWidgets.QTabBar):
         return core.Size(self.iconSize())
 
     def set_tab(
-        self, index: int, position: PositionStr, widget: Optional[QtWidgets.QWidget]
+        self, index: int, position: PositionStr, widget: QtWidgets.QWidget | None
     ) -> None:
         self.setTabButton(index, POSITIONS[position], widget)  # type: ignore
 
